@@ -1,6 +1,6 @@
 #!/bin/bash
 # Copyright 2010-2019, Intel Corporation, All Rights Reserved.
-# link_install.sh - makes symbolic links and other environment changes 
+# link_install.sh - makes symbolic links and other environment changes
 
 # The  source code,  information and material  ("Material")  contained herein is
 # owned  by  Intel  Corporation or its suppliers or licensors, and title to such
@@ -204,14 +204,14 @@ ICP12_REPORT() {
 # create necessary links
 ICP12_MKLINKS() {
     VERBOSE_PRINT "ICP12_MKLINKS()"
-    
+
     SET_ARCH
 
     # Intel TOP Directory - create if not exist, exit in case of error
     # NOTE: we should not create links structure in other than /opt/intel dir
     if [ "$TOP_INTEL_DIR_EXISTS" = "0" ]; then
         ICP12_CREATE_DIR $TOP_INTEL_DIR
-        if [ "$?" != "0" ]; then 
+        if [ "$?" != "0" ]; then
             echo "warning: cannot create TOP_INTEL_DIR $TOP_INTEL_DIR"
             exit 1
         fi
@@ -245,8 +245,8 @@ ICP12_MKLINKS() {
             fi
             pushd $(dirname ${DIR_PATH}) &> /dev/null
             if [ -f "$LINK_POINT" ]; then
-                # creating links on files                
-                ICP12_CREATE_FILE_LINK ${LINK_POINT} ${DIR_PATH}   
+                # creating links on files
+                ICP12_CREATE_FILE_LINK ${LINK_POINT} ${DIR_PATH}
             else
                 # creating links on directory
                 ICP12_CREATE_DIR_LINK ${LINK_POINT} ${DIR_PATH} ${IS_REWRITABLE}
@@ -255,69 +255,65 @@ ICP12_MKLINKS() {
         fi
     done
 
-    # copy this script
-    ICP12_COPY_FILE $FULL_PROGRAM_PATH $INTEL_BIN_DIR
-    ICP12_COPY_FILE $FULL_PROGRAM_PATH $INTEL_COMPLIB_DIR/linux/bin
-
     # check which version directories "lib", "include" points to and try to set up all links in bin by binaries from this version
-    CPRO_VER_SET=$(readlink $INTEL_COMPLIB_2019_LIB_DIR | sed "s/^.*\(compilers_and_libraries_2019.[0-9]\.[0-9][0-9][0-9]\).*$/\1/g")
+    CPRO_VER_SET=$(readlink $INTEL_COMPLIB_2020_LIB_DIR | sed "s/^.*\(compilers_and_libraries_2020.[0-9]\.[0-9][0-9][0-9]\).*$/\1/g")
     if [ -n "$CPRO_VER_SET" ]; then
         PACKAGEID="$CPRO_VER_SET"
         PKG_INSTALL_DESTINATION="$TOP_INTEL_DIR/$PACKAGEID"
     fi
-    
+
     #create folder for ia32 links
-    [ -d $PKG_INSTALL_DESTINATION/linux/bin/ia32 ] && mkdir -p $INTEL_COMPLIB_2019_BIN_DIR/ia32
+    [ -d $PKG_INSTALL_DESTINATION/linux/bin/ia32 ] && mkdir -p $INTEL_COMPLIB_2020_BIN_DIR/ia32
     #create folder for intel64 links
-    [ -d $PKG_INSTALL_DESTINATION/linux/bin/intel64 ] && mkdir -p $INTEL_COMPLIB_2019_BIN_DIR/intel64
-	            	
+    [ -d $PKG_INSTALL_DESTINATION/linux/bin/intel64 ] && mkdir -p $INTEL_COMPLIB_2020_BIN_DIR/intel64
+
     # create links for binary and non-env script program files
     for THIS_FILE in $INTEL_PROGRAM_FILES_LIST
     do
-        
-        # creating links on files in INTEL_COMPLIB_2019_BIN_DIR dir for ia32 architecture
-        pushd $INTEL_COMPLIB_2019_BIN_DIR/ia32 &> /dev/null
-        ICP12_CREATE_FILE_LINK ../../../../$PACKAGEID/linux/bin/ia32/$THIS_FILE $INTEL_COMPLIB_2019_BIN_DIR/ia32/$THIS_FILE
+
+        # creating links on files in INTEL_COMPLIB_2020_BIN_DIR dir for ia32 architecture
+        pushd $INTEL_COMPLIB_2020_BIN_DIR/ia32 &> /dev/null
+        ICP12_CREATE_FILE_LINK ../../../../$PACKAGEID/linux/bin/ia32/$THIS_FILE $INTEL_COMPLIB_2020_BIN_DIR/ia32/$THIS_FILE
         popd &>/dev/null
-        pushd $INTEL_COMPLIB_2019_BIN_DIR/intel64 &> /dev/null
-        ICP12_CREATE_FILE_LINK ../../../../$PACKAGEID/linux/bin/intel64/$THIS_FILE $INTEL_COMPLIB_2019_BIN_DIR/intel64/$THIS_FILE
+        pushd $INTEL_COMPLIB_2020_BIN_DIR/intel64 &> /dev/null
+        ICP12_CREATE_FILE_LINK ../../../../$PACKAGEID/linux/bin/intel64/$THIS_FILE $INTEL_COMPLIB_2020_BIN_DIR/intel64/$THIS_FILE
         popd &>/dev/null
-        
-		# creating links on files in INTEL_BIN_DIR dir
+
+        # creating links on files in INTEL_BIN_DIR dir
         pushd $INTEL_BIN_DIR &>/dev/null
-        ICP12_CREATE_FILE_LINK ../compilers_and_libraries_2019/linux/bin/$ARCH/$THIS_FILE $INTEL_BIN_DIR/$THIS_FILE
+        ICP12_CREATE_FILE_LINK ../compilers_and_libraries_2020/linux/bin/$ARCH/$THIS_FILE $INTEL_BIN_DIR/$THIS_FILE
         popd &> /dev/null
     done
 
     # actions below we make always regardless what is installed (compiler links should anyway be updated by current compiler)
-    # copy environment scripts and make script links 
+    # copy environment scripts and make script links
     for THIS_FILE in $INTEL_ENV_FILE_LIST
     do
         # if env file is compilervars.[c]sh
         if [ "x$(echo $THIS_FILE | grep compilervars)" != "x" ]; then
             filetarget=$(find $PKG_INSTALL_DESTINATION -name "$THIS_FILE" -type f)
             filedestination=$(echo ${THIS_FILE} | sed -e"s/_global//g")
-            cp -p ${filetarget} "$INTEL_COMPLIB_2019_BIN_DIR/${filedestination}" &>/dev/null
-            VERBOSE_PRINT "Copied $THIS_FILE to $INTEL_COMPLIB_2019_BIN_DIR/${filedestination}"
+            cp -p ${filetarget} "$INTEL_COMPLIB_2020_BIN_DIR/${filedestination}" &>/dev/null
+            VERBOSE_PRINT "Copied $THIS_FILE to $INTEL_COMPLIB_2020_BIN_DIR/${filedestination}"
 
             pushd $INTEL_BIN_DIR &>/dev/null
-            ICP12_CREATE_FILE_LINK ../compilers_and_libraries_2019/linux/bin/${filedestination} $INTEL_BIN_DIR/${filedestination}
+            ICP12_CREATE_FILE_LINK ../compilers_and_libraries_2020/linux/bin/${filedestination} $INTEL_BIN_DIR/${filedestination}
             popd &> /dev/null
         else
             # don't create ifortvars.[c]sh if fortran isn't installed
             if [ "x$(echo $THIS_FILE | grep fort)" != "x" ] && [ ! -L $INTEL_BIN_DIR/ifort ]; then
                 VERBOSE_PRINT "We should not have $THIS_FILE link, because Fortran package isn't installed"
-		VERBOSE_PRINT "...trying to remove $INTEL_BIN_DIR/$THIS_FILE"
+                VERBOSE_PRINT "...trying to remove $INTEL_BIN_DIR/$THIS_FILE"
                 pushd $INTEL_BIN_DIR &>/dev/null
-		rm $RM_OPTIONS $THIS_FILE &>/dev/null
+                rm $RM_OPTIONS $THIS_FILE &>/dev/null
                 popd &>/dev/null
                 continue
             fi
             if [ "x$(echo $THIS_FILE | grep icc)" != "x" ] && [ ! -L $INTEL_BIN_DIR/icc ]; then
-		VERBOSE_PRINT "We should not have $THIS_FILE link, because C++ package isn't installed (probably it was removed)"
-		VERBOSE_PRINT "...trying to remove $INTEL_BIN_DIR/$THIS_FILE"
+                VERBOSE_PRINT "We should not have $THIS_FILE link, because C++ package isn't installed (probably it was removed)"
+                VERBOSE_PRINT "...trying to remove $INTEL_BIN_DIR/$THIS_FILE"
                 pushd $INTEL_BIN_DIR &>/dev/null
-		rm $RM_OPTIONS $THIS_FILE &>/dev/null
+                rm $RM_OPTIONS $THIS_FILE &>/dev/null
                 popd &>/dev/null
                 continue
             fi
@@ -328,9 +324,9 @@ ICP12_MKLINKS() {
             popd &>/dev/null
         fi
     done
-    
+
     # support of SC foldermap
-    pushd $INTEL_COMPLIB_2019_DIR &>/dev/null
+    pushd $INTEL_COMPLIB_2020_DIR &>/dev/null
     ICP12_CREATE_FILE_LINK "../$PACKAGEID/foldermap.sc.xml" "foldermap.sc.xml"
     popd &>/dev/null
     # support of SC foldermap - end
@@ -342,8 +338,8 @@ ICP12_RMLINKS() {
     VERBOSE_PRINT "ICP12_RMLINKS()"
 
     # support of SC foldermap
-    if [ -e "${INTEL_COMPLIB_2019_DIR}/foldermap.sc.xml" ] ; then
-        rm $RM_OPTIONS "${INTEL_COMPLIB_2019_DIR}/foldermap.sc.xml" &>/dev/null
+    if [ -e "${INTEL_COMPLIB_2020_DIR}/foldermap.sc.xml" ] ; then
+        rm $RM_OPTIONS "${INTEL_COMPLIB_2020_DIR}/foldermap.sc.xml" &>/dev/null
     fi
     # support of SC foldermap - end
 
@@ -396,7 +392,7 @@ VERBOSE_PRINT() {
 FIND_LATEST_PROD_INSTANCE () {
     VERBOSE_PRINT "FIND_LATEST_PROD_INSTANCE()"
 
-    CPRO_INSTALLED_VERSIONS=$(ls -A $TOP_INTEL_DIR | grep 'compilers_and_libraries_' | sed 's/compilers_and_libraries_//g' | grep -e '2019' | grep -ve '^2019$' | sort -gr)
+    CPRO_INSTALLED_VERSIONS=$(ls -A $TOP_INTEL_DIR | grep 'compilers_and_libraries_' | sed 's/compilers_and_libraries_//g' | grep -e '2020' | grep -ve '^2020$' | sort -gr)
     local CPRO_LATEST_PACKAGE_NUMBER=$(echo "$CPRO_INSTALLED_VERSIONS" | cut -d'.' -f3 | sort -gr | head -1)
 
     if [ -z "$CPRO_INSTALLED_VERSIONS" ]; then
@@ -404,11 +400,11 @@ FIND_LATEST_PROD_INSTANCE () {
         return 1
     else
         # Since versions are sorted in descending type, we can take the first line for getting latest version
-        LATEST_VER=$(echo "$CPRO_INSTALLED_VERSIONS" | grep -e "^2019\.[0-9]*\.${CPRO_LATEST_PACKAGE_NUMBER}$")
+        LATEST_VER=$(echo "$CPRO_INSTALLED_VERSIONS" | grep -e "^2020\.[0-9]*\.${CPRO_LATEST_PACKAGE_NUMBER}$")
     fi
 
     VERBOSE_PRINT "LATEST_VER=$LATEST_VER"
-    
+
     return 0
 }
 
@@ -422,7 +418,7 @@ CHECK_LATEST_VER_WHERE_FILE_PRESENT () {
 
     local file="$1"
     local test_attr="$2"
-    
+
     REPLY_VERSION=''
 
     IFS="$OLD_IFS"
@@ -441,7 +437,7 @@ CHECK_LATEST_VER_WHERE_FILE_PRESENT () {
 }
 
 # -----------------------------------------------------------------------------
-# initialize values for operation of this program 
+# initialize values for operation of this program
 # - invoked with arguments to parent script
 ICP12_INIT() {
     VERBOSE_PRINT "ICP12_INIT()"
@@ -464,7 +460,7 @@ ICP12_INIT() {
        # fi
 
         # reset the package ID to the one provided to script
-        PACKAGEID=$(basename $PKG_INSTALL_DESTINATION) 
+        PACKAGEID=$(basename $PKG_INSTALL_DESTINATION)
     fi
     VERBOSE_PRINT "PACKAGEID=$PACKAGEID"
 
@@ -476,35 +472,36 @@ ICP12_INIT() {
     #       {y,n} - should this entry be rewritable in slave mode? - yes/no
     #       DIR_VAR - variable name containing resolved DIR_PATH (for further usage)
     #       DIR_PATH - directory/link path in link structure
-    #       LINK_POINT - path which link should point to 
+    #       LINK_POINT - path which link should point to
     #
     # NOTE: delimiters (;) between each string are mandatory!
     #       delimeters beewteen items within each string are just spaces
     # NOTE2: if you use some variable in DIR_PATH field, you should screen this variable by "\"
     #        (see structure below for example of usage)
-    # NOTE3: Order of strings is important, because it's order of directories creation and 
+    # NOTE3: Order of strings is important, because it's order of directories creation and
     #        each next string is often based on previous one
 
     LINK_STRUCT="\
 d n  INTEL_BIN_DIR                              \$TOP_INTEL_DIR/bin;\
-d n  INTEL_COMPLIB_2019_DIR                     \$TOP_INTEL_DIR/compilers_and_libraries_2019;\
-d n  INTEL_COMPLIB_2019_Lin_DIR                 \$TOP_INTEL_DIR/compilers_and_libraries_2019/linux;\
-d n  INTEL_COMPLIB_2019_BIN_DIR                 \$INTEL_COMPLIB_2019_Lin_DIR/bin;\
-l n  INTEL_COMPLIB_DIR                          \$TOP_INTEL_DIR/compilers_and_libraries         compilers_and_libraries_2019;\
-l n  INTEL_COMPLIB_2019_PKG_BIN_DIR             \$INTEL_COMPLIB_2019_Lin_DIR/pkg_bin            ../../$PACKAGEID/linux/bin;\
-l n  INTEL_COMPLIB_2019_LIB_DIR                 \$INTEL_COMPLIB_2019_Lin_DIR/lib                ../../$PACKAGEID/linux/compiler/lib;\
-l n  INTEL_COMPLIB_2019_INCLUDE_DIR             \$INTEL_COMPLIB_2019_Lin_DIR/include            ../../$PACKAGEID/linux/compiler/include;\
-l y  INTEL_COMPLIB_2019_TBB_DIR                 \$INTEL_COMPLIB_2019_Lin_DIR/tbb                ../../$PACKAGEID/linux/tbb;\
-l y  INTEL_COMPLIB_2019_PSTL_DIR                \$INTEL_COMPLIB_2019_Lin_DIR/pstl               ../../$PACKAGEID/linux/pstl;\
-l y  INTEL_COMPLIB_2019_MKL_DIR                 \$INTEL_COMPLIB_2019_Lin_DIR/mkl                ../../$PACKAGEID/linux/mkl;\
-l y  INTEL_COMPLIB_2019_IPP_DIR                 \$INTEL_COMPLIB_2019_Lin_DIR/ipp                ../../$PACKAGEID/linux/ipp;\
-l y  INTEL_COMPLIB_2019_IPPCP_DIR               \$INTEL_COMPLIB_2019_Lin_DIR/ippcp              ../../$PACKAGEID/linux/ippcp;\
-l y  INTEL_COMPLIB_2019_MPIRT_DIR               \$INTEL_COMPLIB_2019_Lin_DIR/mpirt              ../../$PACKAGEID/linux/mpirt;\
-l y  INTEL_COMPLIB_2019_MPI_DIR                 \$INTEL_COMPLIB_2019_Lin_DIR/mpi                ../../$PACKAGEID/linux/mpi;\
-l y  INTEL_COMPLIB_2019_DAAL_DIR                \$INTEL_COMPLIB_2019_Lin_DIR/daal               ../../$PACKAGEID/linux/daal;\
-l y  INTEL_COMPLIB_2019_DEBUGGER_DIR            \$INTEL_COMPLIB_2019_Lin_DIR/debugger           ../../debugger_2019;\
-l n  INTEL_COMPLIB_2019_DOCUMENTATION_DIR       \$INTEL_COMPLIB_2019_Lin_DIR/documentation      ../../documentation_2019;\
-l n  INTEL_COMPLIB_2019_MAN_DIR                 \$INTEL_COMPLIB_2019_Lin_DIR/man                documentation/en/man;\
+d n  INTEL_COMPLIB_2020_DIR                     \$TOP_INTEL_DIR/compilers_and_libraries_2020;\
+d n  INTEL_COMPLIB_2020_Lin_DIR                 \$TOP_INTEL_DIR/compilers_and_libraries_2020/linux;\
+d n  INTEL_COMPLIB_2020_BIN_DIR                 \$INTEL_COMPLIB_2020_Lin_DIR/bin;\
+l n  INTEL_COMPLIB_DIR                          \$TOP_INTEL_DIR/compilers_and_libraries         compilers_and_libraries_2020;\
+l n  INTEL_COMPLIB_2020_PKG_BIN_DIR             \$INTEL_COMPLIB_2020_Lin_DIR/pkg_bin            ../../$PACKAGEID/linux/bin;\
+l n  INTEL_COMPLIB_2020_LIB_DIR                 \$INTEL_COMPLIB_2020_Lin_DIR/lib                ../../$PACKAGEID/linux/compiler/lib;\
+l n  INTEL_COMPLIB_2020_INCLUDE_DIR             \$INTEL_COMPLIB_2020_Lin_DIR/include            ../../$PACKAGEID/linux/compiler/include;\
+l y  INTEL_COMPLIB_2020_TBB_DIR                 \$INTEL_COMPLIB_2020_Lin_DIR/tbb                ../../$PACKAGEID/linux/tbb;\
+l y  INTEL_COMPLIB_2020_PSTL_DIR                \$INTEL_COMPLIB_2020_Lin_DIR/pstl               ../../$PACKAGEID/linux/pstl;\
+l y  INTEL_COMPLIB_2020_MKL_DIR                 \$INTEL_COMPLIB_2020_Lin_DIR/mkl                ../../$PACKAGEID/linux/mkl;\
+l y  INTEL_COMPLIB_2020_IPP_DIR                 \$INTEL_COMPLIB_2020_Lin_DIR/ipp                ../../$PACKAGEID/linux/ipp;\
+l y  INTEL_COMPLIB_2020_IPPCP_DIR               \$INTEL_COMPLIB_2020_Lin_DIR/ippcp              ../../$PACKAGEID/linux/ippcp;\
+l y  INTEL_COMPLIB_2020_MPIRT_DIR               \$INTEL_COMPLIB_2020_Lin_DIR/mpirt              ../../$PACKAGEID/linux/mpirt;\
+l y  INTEL_COMPLIB_2020_MPI_DIR                 \$INTEL_COMPLIB_2020_Lin_DIR/mpi                ../../$PACKAGEID/linux/mpi;\
+l y  INTEL_COMPLIB_2020_DAAL_DIR                \$INTEL_COMPLIB_2020_Lin_DIR/daal               ../../$PACKAGEID/linux/daal;\
+l y  INTEL_COMPLIB_2020_DEBUGGER_DIR            \$INTEL_COMPLIB_2020_Lin_DIR/debugger           ../../debugger_2020;\
+l n  INTEL_COMPLIB_2020_DOCUMENTATION_DIR       \$INTEL_COMPLIB_2020_Lin_DIR/documentation      ../../documentation_2020;\
+l n  INTEL_COMPLIB_2020_SAMPLES_DIR             \$INTEL_COMPLIB_2020_Lin_DIR/samples            ../../samples_2020;\
+l n  INTEL_COMPLIB_2020_MAN_DIR                 \$INTEL_COMPLIB_2020_Lin_DIR/man                documentation/en/man;\
 l n  INTEL_LIB_DIR                              \$TOP_INTEL_DIR/lib                             compilers_and_libraries/linux/lib;\
 l n  INTEL_INCLUDE_DIR                          \$TOP_INTEL_DIR/include                         compilers_and_libraries/linux/include;\
 l n  INTEL_MAN_DIR                              \$TOP_INTEL_DIR/man                             compilers_and_libraries/linux/man;\
@@ -653,7 +650,7 @@ PARSE_CMD_ARGS() {
     sflg=0
     uflg=0
     parse_cmd_err=0
-    
+
     while getopts ":iesup:l:vm:" opt; do
         case $opt in
             i)
@@ -711,7 +708,7 @@ PARSE_CMD_ARGS() {
                     parse_cmd_err=2
                 fi
                 ;;
-                
+
             \?)
                 echo "Invalid option: -$OPTARG" >&2
                 exit 1
@@ -722,7 +719,7 @@ PARSE_CMD_ARGS() {
                 ;;
         esac
     done
-   
+
     case $parse_cmd_err in
         1)
             echo "error in parsing command line arguments: parameters -i -u -e or -s are alternatives"
@@ -740,7 +737,7 @@ PARSE_CMD_ARGS() {
 # show usage
 ICP12_USAGE() {
     VERBOSE_PRINT "ICP12_TRAP()"
-    
+
     echo "Script $0 - USAGE"
     echo
     echo "$0 -i|-e|-s|-u [ -p <PATH_TO_PACKAGE> ] [ -l <PATH_TO_LINKS> ] [ -m <MODE> ] [ -v ]"
@@ -753,7 +750,7 @@ ICP12_USAGE() {
     echo "  -v                  - enables VERBOSE mode"
     echo
     echo "Examples:"
-    echo 
+    echo
     echo "$0 -s"
     echo "     reports current status of installation and links"
     echo
@@ -775,13 +772,13 @@ OLD_IFS=$IFS
 IFS=";"
 
 # locally hardcoded for test purposes
-#DEFAULT_PACKAGEID="compilers_and_libraries_2019.0.001"
-DEFAULT_PACKAGEID="compilers_and_libraries_2019.4.243"
+#DEFAULT_PACKAGEID="compilers_and_libraries_2020.0.001"
+DEFAULT_PACKAGEID="compilers_and_libraries_2020.0.166"
 
 PACKAGEID=$DEFAULT_PACKAGEID
 
-PACKAGENUM=$(echo $PACKAGEID | sed -e"s/compilers_and_libraries_2019\.[0-9]\.//g")
-    
+PACKAGENUM=$(echo $PACKAGEID | sed -e"s/compilers_and_libraries_2020\.[0-9]\.//g")
+
 # parse script's command line
 PARSE_CMD_ARGS $@
 
