@@ -57,6 +57,9 @@ int ComputeMG_ref(const SparseMatrix & A, const Vector & r, Vector & x);
 */
 int ComputeMG(const SparseMatrix  & A, const Vector & r, Vector & x)
 {
+#ifdef HPCG_LOCAL_LONG_LONG
+    ComputeMG_ref(A,r,x);
+#else
     int ierr = 0;
 
     if (A.mgData!=0) // Go to next coarse level if defined
@@ -104,6 +107,6 @@ int ComputeMG(const SparseMatrix  & A, const Vector & r, Vector & x)
 
         if ( status != SPARSE_STATUS_SUCCESS ) return 1;
     }
-
+#endif
     return 0;
 }
