@@ -60,6 +60,9 @@
 
 int ComputeSPMV( const SparseMatrix & A, Vector & x, Vector & y)
 {
+#ifdef HPCG_LOCAL_LONG_LONG
+    ComputeSPMV_ref(A,x,y);
+#else
     sparse_status_t status = SPARSE_STATUS_SUCCESS;
     struct optData *optData = (struct optData *)A.optimizationData;
     struct matrix_descr descr;
@@ -89,7 +92,7 @@ int ComputeSPMV( const SparseMatrix & A, Vector & x, Vector & y)
             y.values[ind] += optData->dtmp[i];
         }
     }
-
+#endif
     return 0;
 }
 
