@@ -46,7 +46,7 @@
 
 #include "mkl.h"
 /*!
-  Routine to one step of symmetrix Gauss-Seidel:
+  Routine to compute one step of symmetric Gauss-Seidel:
 
   Assumption about the structure of matrix A:
   - Each row 'i' of the matrix has nonzero diagonal value whose address is matrixDiagonal[i]
@@ -62,8 +62,8 @@
        - For simplicity we include the diagonal contribution in the for-j loop, then correct the sum after
 
   @param[in]  A the known system matrix
-  @param[in]  x the input vector
-  @param[out] y On exit contains the result of one symmetric GS sweep with x as the RHS.
+  @param[in]  r the input vector
+  @param[inout] x On entry, x should contain relevant values, on exit x contains the result of one symmetric GS sweep with r as the RHS.
 
   @return returns 0 upon success and non-zero otherwise
 
