@@ -49,6 +49,53 @@ void ExchangeHalo(const SparseMatrix & A, Vector & x) {
   // Extract Matrix pieces
   if ( A.geom->size > 1 )
   {
+#ifdef HPCG_LOCAL_LONG_LONG
+  // using MPI_ISend and MPI_IRecv since MPI_Alltoallv cannot handle long long arguments
+
+  local_int_t localNumberOfRows = A.localNumberOfRows;
+  int num_neighbors = A.numberOfSendNeighbors;
+  local_int_t * receiveLength = A.receiveLength;
+  local_int_t * sendLength = A.sendLength;
+  int * neighbors = A.neighbors;
+  double * sendBuffer = A.sendBuffer;
+  local_int_t totalToBeSent = A.totalToBeSent;
+  local_int_t * elementsToSend = A.elementsToSend;
+
+  double * const xv = x.values;
+
+  int MPI_MY_TAG = 99;
+  MPI_Request * request = new MPI_Request[num_neighbors];
+
+  // Externals are at end of locals
+  double * x_external = (double *) xv + localNumberOfRows;
+
+  // Post receives first
+  for (int i = 0; i < num_neighbors; i++) {
+    int n_recv = receiveLength[i];
+    MPI_Irecv(x_external, n_recv, MPI_DOUBLE, neighbors[i], MPI_MY_TAG, MPI_COMM_WORLD, request+i);
+    x_external += n_recv;
+  }
+
+  // Fill up send buffer
+  for (local_int_t i=0; i<totalToBeSent; i++) sendBuffer[i] = xv[elementsToSend[i]];
+
+  // Send to each neighbor
+  for (int i = 0; i < num_neighbors; i++) {
+    int n_send = sendLength[i];
+    MPI_Send(sendBuffer, n_send, MPI_DOUBLE, neighbors[i], MPI_MY_TAG, MPI_COMM_WORLD);
+    sendBuffer += n_send;
+  }
+
+  // Complete the reads issued above
+  MPI_Status status;
+  for (int i = 0; i < num_neighbors; i++) {
+    if ( MPI_Wait(request+i, &status) ) {
+      exit(-1); // TODO: have better error exit
+    }
+  }
+
+  delete [] request;
+#else
       local_int_t localNumberOfRows = A.localNumberOfRows;
       double * sendBuffer = A.sendBuffer;
       local_int_t totalToBeSent = A.totalToBeSent;
@@ -65,6 +112,7 @@ void ExchangeHalo(const SparseMatrix & A, Vector & x) {
       for (local_int_t i=0; i<totalToBeSent; i++) sendBuffer[i] = xv[elementsToSend[i]];
 
       MPI_Alltoallv( sendBuffer, A.scounts, A.sdispls, MPI_DOUBLE, x_external, A.rcounts, A.rdispls, MPI_DOUBLE, MPI_COMM_WORLD);
+#endif
   }
   return;
 }
