@@ -82,21 +82,28 @@ void GenerateCoarseProblem(const SparseMatrix & Af) {
   #pragma omp parallel for
 #endif
   for (local_int_t izc=0; izc<nzc; ++izc) {
-	  local_int_t izf = 2*izc;
-	  for (local_int_t iyc=0; iyc<nyc; ++iyc) {
-		  local_int_t iyf = 2*iyc;
-		  for (local_int_t ixc=0; ixc<nxc; ++ixc) {
-			  local_int_t ixf = 2*ixc;
-			  local_int_t currentCoarseRow = izc*nxc*nyc+iyc*nxc+ixc;
-			  local_int_t currentFineRow = izf*nxf*nyf+iyf*nxf+ixf;
-			  f2cOperator[currentCoarseRow] = currentFineRow;
-		  } // end iy loop
-	  } // end even iz if statement
+    local_int_t izf = 2*izc;
+    for (local_int_t iyc=0; iyc<nyc; ++iyc) {
+      local_int_t iyf = 2*iyc;
+      for (local_int_t ixc=0; ixc<nxc; ++ixc) {
+        local_int_t ixf = 2*ixc;
+        local_int_t currentCoarseRow = izc*nxc*nyc+iyc*nxc+ixc;
+        local_int_t currentFineRow = izf*nxf*nyf+iyf*nxf+ixf;
+        f2cOperator[currentCoarseRow] = currentFineRow;
+      } // end iy loop
+    } // end even iz if statement
   } // end iz loop
 
   // Construct the geometry and linear system
   Geometry * geomc = new Geometry;
-  GenerateGeometry(Af.geom->size, Af.geom->rank, Af.geom->numThreads, nxc, nyc, nzc, geomc);
+  local_int_t zlc = 0; // Coarsen nz for the lower block in the z processor dimension
+  local_int_t zuc = 0; // Coarsen nz for the upper block in the z processor dimension
+  int pz = Af.geom->pz;
+  if (pz>0) {
+    zlc = Af.geom->partz_nz[0]/2; // Coarsen nz for the lower block in the z processor dimension
+    zuc = Af.geom->partz_nz[1]/2; // Coarsen nz for the upper block in the z processor dimension
+  }
+  GenerateGeometry(Af.geom->size, Af.geom->rank, Af.geom->numThreads, Af.geom->pz, zlc, zuc, nxc, nyc, nzc, Af.geom->npx, Af.geom->npy, Af.geom->npz, geomc);
 
   SparseMatrix * Ac = new SparseMatrix;
   InitializeSparseMatrix(*Ac, geomc);
@@ -115,7 +122,6 @@ void GenerateCoarseProblem(const SparseMatrix & Af) {
   Af.Ac = Ac;
   MGData * mgData = new MGData;
   InitializeMGData(f2cOperator, rc, xc, Axf, *mgData);
-  //printf("%p, %d\n",mgData,localNumberOfRows);fflush(0);
   Af.mgData = mgData;
 
   return;
