@@ -28,5 +28,5 @@
 #ifndef GENERATEGEOMETRY_HPP
 #define GENERATEGEOMETRY_HPP
 #include "Geometry.hpp"
-void GenerateGeometry(int size, int rank, int numThreads, int nx, int ny, int nz, Geometry * geom);
+void GenerateGeometry(int size, int rank, int numThreads, int pz, local_int_t zl, local_int_t zu, local_int_t nx, local_int_t ny, local_int_t nz, int npx, int npy, int npz, Geometry * geom);
 #endif // GENERATEGEOMETRY_HPP
