@@ -75,15 +75,15 @@ void GenerateProblem(SparseMatrix & A, Vector * b, Vector * x, Vector * xexact)
   global_int_t nx = A.geom->nx;
   global_int_t ny = A.geom->ny;
   global_int_t nz = A.geom->nz;
-  global_int_t npx = A.geom->npx;
-  global_int_t npy = A.geom->npy;
-  global_int_t npz = A.geom->npz;
-  global_int_t ipx = A.geom->ipx;
-  global_int_t ipy = A.geom->ipy;
-  global_int_t ipz = A.geom->ipz;
-  global_int_t gnx = nx*npx;
-  global_int_t gny = ny*npy;
-  global_int_t gnz = nz*npz;
+  global_int_t gnx = A.geom->gnx;
+  global_int_t gny = A.geom->gny;
+  global_int_t gnz = A.geom->gnz;
+  global_int_t gix0 = A.geom->gix0;
+  global_int_t giy0 = A.geom->giy0;
+  global_int_t giz0 = A.geom->giz0;
+  //global_int_t ipx = A.geom->ipx;
+  //global_int_t ipy = A.geom->ipy;
+  //global_int_t ipz = A.geom->ipz;
   double omp1,omp2;
 
   local_int_t localNumberOfRows = nx*ny*nz; // This is the size of our subblock
@@ -91,10 +91,11 @@ void GenerateProblem(SparseMatrix & A, Vector * b, Vector * x, Vector * xexact)
   assert(localNumberOfRows>0); // Throw an exception of the number of rows is less than zero (can happen if int overflow)
   local_int_t numberOfNonzerosPerRow = 27; // We are approximating a 27-point finite element/volume/difference 3D stencil
 
-  global_int_t totalNumberOfRows = ((global_int_t) localNumberOfRows)*((global_int_t) A.geom->size); // Total number of grid points in mesh
+  global_int_t totalNumberOfRows = gnx*gny*gnz; // Total number of grid points in mesh
   // If this assert fails, it most likely means that the global_int_t is set to int and should be set to long long
   assert(totalNumberOfRows>0); // Throw an exception of the number of rows is less than zero (can happen if int overflow)
 //  double t1 = dsecnd();
+
   // Allocate arrays that are of length localNumberOfRows
   char * nonzerosInRow = (char*) MKL_malloc(sizeof(char)*localNumberOfRows, ALIGN);
   global_int_t ** mtxIndG = (global_int_t**) MKL_malloc(sizeof(global_int_t*)*localNumberOfRows, ALIGN);
@@ -228,9 +229,9 @@ void GenerateProblem(SparseMatrix & A, Vector * b, Vector * x, Vector * xexact)
         
         for (local_int_t ix=1; ix<nx-1; ix++)
         {
-            global_int_t giy = ipy*ny+iy;
-            global_int_t giz = ipz*nz+iz;
-            global_int_t gix = ipx*nx+ix;
+            global_int_t giy = giy0+iy; //ipy*ny+iy;
+            global_int_t giz = giz0+iz; //ipz*nz+iz;
+            global_int_t gix = gix0+ix; //ipx*nx+ix;
             local_int_t currentLocalRow = iz*nx*ny+iy*nx+ix;
             global_int_t currentGlobalRow = giz*gnx*gny+giy*gnx+gix;
             A.localToGlobalMap[currentLocalRow ] = currentGlobalRow;
@@ -263,8 +264,20 @@ void GenerateProblem(SparseMatrix & A, Vector * b, Vector * x, Vector * xexact)
                 *(currentIndexPointerL + 6) = offset + nx - 1;
                 *(currentIndexPointerL + 7) = offset + nx;
                 *(currentIndexPointerL + 8) = offset + nx + 1;
+                
+                global_int_t offsetG = currentGlobalRow + sz*gny*gnx;
+                *(currentIndexPointerG + 0) = offsetG - gnx - 1;
+                *(currentIndexPointerG + 1) = offsetG - gnx;
+                *(currentIndexPointerG + 2) = offsetG - gnx + 1;
+                *(currentIndexPointerG + 3) = offsetG - 1;
+                *(currentIndexPointerG + 4) = offsetG;
+                *(currentIndexPointerG + 5) = offsetG + 1;
+                *(currentIndexPointerG + 6) = offsetG + gnx - 1;
+                *(currentIndexPointerG + 7) = offsetG + gnx;
+                *(currentIndexPointerG + 8) = offsetG + gnx + 1;
                 currentValuePointer  += 9;
                 currentIndexPointerL += 9;
+                currentIndexPointerG += 9;
             } // end sz loop
             *(currentValuePointer - 14) = 26.0;
             matrixDiagonal[currentLocalRow] = currentValuePointer - 14;
@@ -280,35 +293,35 @@ void GenerateProblem(SparseMatrix & A, Vector * b, Vector * x, Vector * xexact)
 #pragma omp for
 #endif
     for (int i = 0; i < A.numOfBoundaryRows; i++) {
-    local_int_t currentLocalRow = A.boundaryRows[i];
+        local_int_t currentLocalRow = A.boundaryRows[i];
 
-    local_int_t iz = currentLocalRow/(ny*nx);
-    local_int_t iy = currentLocalRow/nx%ny;
-    local_int_t ix = currentLocalRow%nx;
+        local_int_t iz = currentLocalRow/(ny*nx);
+        local_int_t iy = currentLocalRow/nx%ny;
+        local_int_t ix = currentLocalRow%nx;
 
-          global_int_t giz = ipz*nz+iz;
-          global_int_t giy = ipy*ny+iy;
-          global_int_t gix = ipx*nx+ix;
+        global_int_t giz = giz0+iz;   //ipz*nz+iz;
+        global_int_t giy = giy0+iy;   //ipy*ny+iy;
+        global_int_t gix = gix0+ix;   //ipx*nx+ix;
           
-          global_int_t sz_begin = std::max<global_int_t>(-1, -giz);
-          global_int_t sz_end = std::min<global_int_t>(1, gnz - giz - 1);
+        global_int_t sz_begin = std::max<global_int_t>(-1, -giz);
+        global_int_t sz_end = std::min<global_int_t>(1, gnz - giz - 1);
           
-          global_int_t sy_begin = std::max<global_int_t>(-1, -giy);
-          global_int_t sy_end = std::min<global_int_t>(1, gny - giy - 1);
+        global_int_t sy_begin = std::max<global_int_t>(-1, -giy);
+        global_int_t sy_end = std::min<global_int_t>(1, gny - giy - 1);
           
-          global_int_t sx_begin = std::max<global_int_t>(-1, -gix);
-          global_int_t sx_end = std::min<global_int_t>(1, gnx - gix - 1);
+        global_int_t sx_begin = std::max<global_int_t>(-1, -gix);
+        global_int_t sx_end = std::min<global_int_t>(1, gnx - gix - 1);
 
-//          local_int_t currentLocalRow = iz*nx*ny+iy*nx+ix;
+//        local_int_t currentLocalRow = iz*nx*ny+iy*nx+ix;
 
-          global_int_t currentGlobalRow = giz*gnx*gny+giy*gnx+gix;
-          /*
-          if( A.geom->size > 1 )
-          {
-              #pragma omp critical
-              A.globalToLocalMap[currentGlobalRow] = currentLocalRow;
-          }
-          */
+        global_int_t currentGlobalRow = giz*gnx*gny+giy*gnx+gix;
+        /*
+        if( A.geom->size > 1 )
+        {
+            #pragma omp critical
+            A.globalToLocalMap[currentGlobalRow] = currentLocalRow;
+        }
+        */
         mtxIndG[currentLocalRow]      = A.mtxG + currentLocalRow*numberOfNonzerosPerRow;
         mtxIndL[currentLocalRow]      = A.mtxL + currentLocalRow*numberOfNonzerosPerRow;
         matrixValues[currentLocalRow] = A.mtxA + currentLocalRow*numberOfNonzerosPerRow;
@@ -347,7 +360,7 @@ void GenerateProblem(SparseMatrix & A, Vector * b, Vector * x, Vector * xexact)
         if( b!=0 ) bv[currentLocalRow] = 26.0 - ((double) (numberOfNonzerosInRow-1));
         if( x!=0 ) xv[currentLocalRow] = 0.0;
         if( xexact!=0 ) xexactv[currentLocalRow] = 1.0;
-  }
+    }
 }
     for (int i = 0; i < A.numOfBoundaryRows; i++) {
         local_int_t currentLocalRow = A.boundaryRows[i];
@@ -356,9 +369,9 @@ void GenerateProblem(SparseMatrix & A, Vector * b, Vector * x, Vector * xexact)
         local_int_t iy = currentLocalRow/nx%ny;
         local_int_t ix = currentLocalRow%nx;
         
-        global_int_t giz = ipz*nz+iz;
-        global_int_t giy = ipy*ny+iy;
-        global_int_t gix = ipx*nx+ix;
+        global_int_t giz = giz0+iz; //ipz*nz+iz;
+        global_int_t giy = giy0+iy; //ipy*ny+iy;
+        global_int_t gix = gix0+ix; //ipx*nx+ix;
         global_int_t currentGlobalRow = giz*gnx*gny+giy*gnx+gix;
         A.globalToLocalMap[currentGlobalRow] = currentLocalRow;
     }
