@@ -58,8 +58,9 @@
 
 void OptimizeProblem(SparseMatrix * A, double & t7)
 {
-    double t1 = 0.0;
     t7 = 0.0;
+#ifndef HPCG_LOCAL_LONG_LONG
+    double t1 = 0.0;
   // This function can be used to completely transform any part of the data structures.
   // Right now it does nothing, so compiling with a check for unused variables results in complaints
 
@@ -241,6 +242,9 @@ void OptimizeProblem(SparseMatrix * A, double & t7)
     Ac->optimizationData = optData;
     Ac = Ac->Ac;
     }//while Ac!=NULL
+#else
+    return;
+#endif
 }
 
 // Helper function (see OptimizeProblem.hpp for details)
