@@ -52,7 +52,7 @@ SkipUntilEol(FILE *stream) {
 }
 
 int
-ReadHpcgDat(int *localDimensions, int *secondsPerRun) {
+ReadHpcgDat(int *localDimensions, int *secondsPerRun, int *localProcDimensions) {
   FILE * hpcgStream = fopen("hpcg.dat", "r");
 
   if (! hpcgStream)
@@ -69,10 +69,17 @@ ReadHpcgDat(int *localDimensions, int *secondsPerRun) {
   SkipUntilEol( hpcgStream ); // skip the rest of the second line
 
   if (secondsPerRun!=0) { // Only read number of seconds if the pointer is non-zero
-	  if (fscanf(hpcgStream, "%d", secondsPerRun) != 1 || secondsPerRun[0] < 0)
-		  secondsPerRun[0] = 30 * 60; // 30 minutes
+    if (fscanf(hpcgStream, "%d", secondsPerRun) != 1 || secondsPerRun[0] < 0)
+      secondsPerRun[0] = 30 * 60; // 30 minutes
   }
 
+  SkipUntilEol( hpcgStream ); // skip the rest of the third line
+
+  for (int i = 0; i < 3; ++i)
+    // the user didn't specify (or values are invalid) process dimensions
+    if (fscanf(hpcgStream, "%d", localProcDimensions+i) != 1 || localProcDimensions[i] < 1)
+      localProcDimensions[i] = 0; // value 0 means: "not specified" and it will be fixed later
+
   fclose(hpcgStream);
 
   return 0;
