@@ -28,6 +28,6 @@
 #ifndef READHPCGDAT_HPP
 #define READHPCGDAT_HPP
 
-int ReadHpcgDat(int *localDimensions, int *secondsPerRun);
+int ReadHpcgDat(int *localDimensions, int *secondsPerRun, int *localProcDimensions);
 
 #endif // READHPCGDAT_HPP
