@@ -37,8 +37,9 @@
 
 #include <vector>
 #include "ReportResults.hpp"
-#include "YAML_Element.hpp"
-#include "YAML_Doc.hpp"
+//#include "YAML_Element.hpp"
+//#include "YAML_Doc.hpp"
+#include "OutputFile.hpp"
 #include "OptimizeProblem.hpp"
 
 #ifdef HPCG_DEBUG
@@ -124,7 +125,6 @@ void ReportResults(const SparseMatrix & A, int numberOfMgLevels, int numberOfCgS
     double fnreads_waxpby = (3.0*fniters+fNumberOfCgSets)*2.0*fnrow*sizeof(double); // 3 WAXPBYs with nrow adds and nrow mults
     double fnwrites_waxpby = (3.0*fniters+fNumberOfCgSets)*fnrow*sizeof(double); // 3 WAXPBYs with nrow adds and nrow mults
     double fnreads_sparsemv = (fniters+fNumberOfCgSets)*(fnnz*(sizeof(double)+sizeof(local_int_t)) + fnrow*sizeof(double));// 1 SpMV with nnz reads of values, nnz reads indices,
-                                                                                                                           // plus nrow reads of x
     double fnwrites_sparsemv = (fniters+fNumberOfCgSets)*fnrow*sizeof(double); // 1 SpMV nrow writes
     // Op counts from the multigrid preconditioners
     double fnreads_precond = 0.0;
@@ -229,9 +229,10 @@ void ReportResults(const SparseMatrix & A, int numberOfMgLevels, int numberOfCgS
     sprintf(buf, "n%d-%dp-%dt", A.geom->nx, A.geom->size, A.geom->numThreads);
     std::string fileName(buf);
     // Instantiate YAML document
-    YAML_Doc doc(fileName, "V3.0", "", params.yamlFileName);
-//    YAML_Doc doc("HPCG-Benchmark", "3.0");
-    doc.add("Release date", "November 11, 2015");
+    //YAML_Doc doc(fileName, "V3.0", "", params.yamlFileName);
+    //OutputFile doc("HPCG-Benchmark", "3.1");
+    OutputFile doc(fileName, "V3.1", "", params.yamlFileName);
+    doc.add("Release date", "March 28, 2019");
 
     doc.add("Machine Summary","");
     doc.get("Machine Summary")->add("Distributed Processes",A.geom->size);
@@ -240,7 +241,8 @@ void ReportResults(const SparseMatrix & A, int numberOfMgLevels, int numberOfCgS
     doc.add("Global Problem Dimensions","");
     doc.get("Global Problem Dimensions")->add("Global nx",A.geom->npx*A.geom->nx);
     doc.get("Global Problem Dimensions")->add("Global ny",A.geom->npy*A.geom->ny);
-    doc.get("Global Problem Dimensions")->add("Global nz",A.geom->npz*A.geom->nz);
+    //doc.get("Global Problem Dimensions")->add("Global nz",A.geom->npz*A.geom->nz);
+    doc.get("Global Problem Dimensions")->add("Global nz",A.geom->gnz);
 
     doc.add("Processor Dimensions","");
     doc.get("Processor Dimensions")->add("npx",A.geom->npx);
@@ -251,6 +253,12 @@ void ReportResults(const SparseMatrix & A, int numberOfMgLevels, int numberOfCgS
     doc.get("Local Domain Dimensions")->add("nx",A.geom->nx);
     doc.get("Local Domain Dimensions")->add("ny",A.geom->ny);
     doc.get("Local Domain Dimensions")->add("nz",A.geom->nz);
+    //varied domain dimensions for z-dimension here
+    if (A.geom->npartz > 1) {
+        doc.get("Local Domain Dimensions")->add("pz", A.geom->pz);
+        doc.get("Local Domain Dimensions")->add("zl", A.geom->partz_nz[0]);
+        doc.get("Local Domain Dimensions")->add("zu", A.geom->partz_nz[1]);
+    }
 
     doc.add("########## Problem Summary  ##########","");
 
@@ -383,47 +391,47 @@ void ReportResults(const SparseMatrix & A, int numberOfMgLevels, int numberOfCgS
     //doc.get("Sparse Operations Overheads")->add("Halo exchange time (sec)", (times[6]));
     //doc.get("Sparse Operations Overheads")->add("Halo exchange as percentage of SpMV time", (times[6])/totalSparseMVTime*100.0);
 #endif
-    doc.add("__________ Final Summary __________","");
+    doc.add(" Final Summary ","");
     bool isValidRun = (testcg_data.count_fail==0) && (testsymmetry_data.count_fail==0) && (testnorms_data.pass) && (!global_failure);
     if (isValidRun) {
-        doc.get("__________ Final Summary __________")->add("HPCG result is VALID with a GFLOP/s rating of", totalGflops);
-        doc.get("__________ Final Summary __________")->add("    HPCG 2.4 Rating (for historical value) is", totalGflops24);
+        doc.get(" Final Summary ")->add("HPCG result is VALID with a GFLOP/s rating of", totalGflops);
+        doc.get(" Final Summary ")->add("    HPCG 2.4 Rating (for historical value) is", totalGflops24);
         printf("HPCG result is VALID with a GFLOP/s rating of %lf\n",totalGflops);
       if (!A.isDotProductOptimized) {
-        doc.get("__________ Final Summary __________")->add("Reference version of ComputeDotProduct used","Performance results are most likely suboptimal");
+        doc.get(" Final Summary ")->add("Reference version of ComputeDotProduct used","Performance results are most likely suboptimal");
       }
       if (!A.isSpmvOptimized) {
-        doc.get("__________ Final Summary __________")->add("Reference version of ComputeSPMV used","Performance results are most likely suboptimal");
+        doc.get(" Final Summary ")->add("Reference version of ComputeSPMV used","Performance results are most likely suboptimal");
       }
       if (!A.isMgOptimized) {
         if (A.geom->numThreads>1)
-          doc.get("__________ Final Summary __________")->add("Reference version of ComputeMG used and number of threads greater than 1","Performance results are severely suboptimal");
+          doc.get(" Final Summary ")->add("Reference version of ComputeMG used and number of threads greater than 1","Performance results are severely suboptimal");
         else // numThreads ==1
-          doc.get("__________ Final Summary __________")->add("Reference version of ComputeMG used","Performance results are most likely suboptimal");
+          doc.get(" Final Summary ")->add("Reference version of ComputeMG used","Performance results are most likely suboptimal");
       }
       if (!A.isWaxpbyOptimized) {
-        doc.get("__________ Final Summary __________")->add("Reference version of ComputeWAXPBY used","Performance results are most likely suboptimal");
+        doc.get(" Final Summary ")->add("Reference version of ComputeWAXPBY used","Performance results are most likely suboptimal");
       }
       if (times[0]>=minOfficialTime) {
-        doc.get("__________ Final Summary __________")->add("Please upload results from the YAML file contents to","http://hpcg-benchmark.org");
+        doc.get(" Final Summary ")->add("Please upload results from the YAML file contents to","http://hpcg-benchmark.org");
       }
       else {
-          doc.get("__________ Final Summary __________")->add("Results are valid but execution time (sec) is",times[0]);
+          doc.get(" Final Summary ")->add("Results are valid but execution time (sec) is",times[0]);
           if (quickPath) {
-        	  doc.get("__________ Final Summary __________")->add("     You have selected the QuickPath option", "Results are official for legacy installed systems with confirmation from the HPCG Benchmark leaders.");
-              doc.get("__________ Final Summary __________")->add("     After confirmation please upload results from the YAML file contents to","http://hpcg-benchmark.org");
+        	  doc.get(" Final Summary ")->add("     You have selected the QuickPath option", "Results are official for legacy installed systems with confirmation from the HPCG Benchmark leaders.");
+              doc.get(" Final Summary ")->add("     After confirmation please upload results from the YAML file contents to","http://hpcg-benchmark.org");
 
           }
           else {
-        	  doc.get("__________ Final Summary __________")->add("     Official results execution time (sec) must be at least",minOfficialTime);
+        	  doc.get(" Final Summary ")->add("     Official results execution time (sec) must be at least",minOfficialTime);
           }
       }
     } else {
-      doc.get("__________ Final Summary __________")->add("HPCG result is","INVALID.");
-      doc.get("__________ Final Summary __________")->add("Please review the YAML file contents","You may NOT submit these results for consideration.");
+      doc.get(" Final Summary ")->add("HPCG result is","INVALID.");
+      doc.get(" Final Summary ")->add("Please review the YAML file contents","You may NOT submit these results for consideration.");
     }
 
-    std::string yaml = doc.generateYAML();
+    std::string yaml = doc.generate();
 #ifdef HPCG_DEBUG
     HPCG_fout << yaml;
 #endif
