@@ -88,12 +88,14 @@ int TestCG(SparseMatrix & A, CGData & data, Vector & b, Vector & x, TestCGData &
       ScaleVectorValue(b, i, 1.0e6);
     }
   }
+#ifndef HPCG_LOCAL_LONG_LONG
 //#ifdef MKL
   ReplaceMKLMatrixDiagonal(A, exaggeratedDiagA);
+#else
 //#else
-//  ReplaceMatrixDiagonal(A, exaggeratedDiagA);
+  ReplaceMatrixDiagonal(A, exaggeratedDiagA);
 //#endif
-
+#endif
 
   int niters = 0;
   double normr = 0.0;
@@ -129,12 +131,11 @@ int TestCG(SparseMatrix & A, CGData & data, Vector & b, Vector & x, TestCGData &
 
 
   // Restore matrix diagonal and RHS
-//#ifdef MKL
+#ifndef HPCG_LOCAL_LONG_LONG
   ReplaceMKLMatrixDiagonal(A, origDiagA);
-//#else
-//  ReplaceMatrixDiagonal(A, origDiagA);
-//#endif
-
+#else
+  ReplaceMatrixDiagonal(A, origDiagA);
+#endif
 
   CopyVector(origB, b);
   // Delete vectors
