@@ -40,7 +40,7 @@
 
 struct TestSymmetryData_STRUCT {
   double depsym_spmv;  //!< departure from symmetry for the SPMV kernel
-  double depsym_mg; //!< departure from symmetry for the SYMGS kernel
+  double depsym_mg; //!< departure from symmetry for the MG kernel
   int    count_fail;   //!< number of failures in the symmetry tests
 };
 typedef struct TestSymmetryData_STRUCT TestSymmetryData;
