@@ -41,6 +41,7 @@ const char* NULLDEVICE="/dev/null";
 
 #include <ctime>
 #include <cstdio>
+#include <cstdlib>
 #include <cstring>
 
 #include <fstream>
@@ -60,7 +61,6 @@ startswith(const char * s, const char * prefix) {
   return 1;
 }
 
-
 /*!
   Initializes an HPCG run by obtaining problem parameters (from a file or
   command line) and then broadcasts them to all nodes. It also initializes
@@ -82,24 +82,31 @@ HPCG_Init(int * argc_p, char ** *argv_p, HPCG_Params & params) {
   int argc = *argc_p;
   char ** argv = *argv_p;
   char fname[80];
-  int i, j, iparams[4];
-  char cparams[4][6] = {"--nx=", "--ny=", "--nz=", "-t"};
+  int i, j, *iparams;
+  char cparams[][7] = {"--nx=", "--ny=", "--nz=", "-t", "--pz=", "--zl=", "--zu=", "--npx=", "--npy=", "--npz="};
   time_t rawtime;
   tm * ptm;
+  const int nparams = (sizeof cparams) / (sizeof cparams[0]);
+  bool broadcastParams = false; // Make true if parameters read from file.
+
+  iparams = (int *)malloc(sizeof(int) * nparams);
+
   params.runRealRef = 1;
   params.yamlFileName[0]='\0';
+
   // Initialize iparams
-  for (i = 0; i < 4; ++i) iparams[i] = 0;
+  for (i = 0; i < nparams; ++i) iparams[i] = 0;
 
   /* for sequential and some MPI implementations it's OK to read first three args */
-  for (i = 0; i < 4; ++i)
+  for (i = 0; i < nparams; ++i)
     if (argc <= i+1 || sscanf(argv[i+1], "%d", iparams+i) != 1 || iparams[i] < 10) iparams[i] = 0;
 
   /* for some MPI environments, command line arguments may get complicated so we need a prefix */
   for (i = 1; i <= argc && argv[i]; ++i)
-    for (j = 0; j < 4; ++j)
+    for (j = 0; j < nparams; ++j)
       if (startswith(argv[i], cparams[j]))
-        if (sscanf(argv[i]+strlen(cparams[j]), "%d", iparams+j) != 1 || iparams[j] < 10) iparams[j] = 0;
+        if (sscanf(argv[i]+strlen(cparams[j]), "%d", iparams+j) != 1) 
+          iparams[j] = 0;
 
   /*Check for run-real-ref*/
   for (i = 1; i <= argc && argv[i]; ++i)
@@ -122,9 +129,10 @@ HPCG_Init(int * argc_p, char ** *argv_p, HPCG_Params & params) {
 
   // Check if --rt was specified on the command line
   int * rt  = iparams+3;  // Assume runtime was not specified and will be read from the hpcg.dat file
-  if (! iparams[3]) rt = 0; // If --rt was specified, we already have the runtime, so don't read it from file
+  if (iparams[3]) rt = 0; // If --rt was specified, we already have the runtime, so don't read it from file
   if (! iparams[0] && ! iparams[1] && ! iparams[2]) { /* no geometry arguments on the command line */
-    ReadHpcgDat(iparams, rt);
+    ReadHpcgDat(iparams, rt, iparams+7);
+    broadcastParams = true;
   }
 
   int nn = 0;
@@ -153,7 +161,9 @@ HPCG_Init(int * argc_p, char ** *argv_p, HPCG_Params & params) {
 
 // Broadcast values of iparams to all MPI processes
 #ifndef HPCG_NO_MPI
-  MPI_Bcast( iparams, 4, MPI_INT, 0, MPI_COMM_WORLD );
+  if (broadcastParams) {
+    MPI_Bcast( iparams, nparams, MPI_INT, 0, MPI_COMM_WORLD );
+  }
 #endif
 
   params.nx = iparams[0];
@@ -161,6 +171,13 @@ HPCG_Init(int * argc_p, char ** *argv_p, HPCG_Params & params) {
   params.nz = iparams[2];
 
   params.runningTime = iparams[3];
+  params.pz = iparams[4];
+  params.zl = iparams[5];
+  params.zu = iparams[6];
+
+  params.npx = iparams[7];
+  params.npy = iparams[8];
+  params.npz = iparams[9];
 
 #ifndef HPCG_NO_MPI
   MPI_Comm_rank( MPI_COMM_WORLD, &params.comm_rank );
@@ -179,22 +196,22 @@ HPCG_Init(int * argc_p, char ** *argv_p, HPCG_Params & params) {
 
   time ( &rawtime );
   ptm = localtime(&rawtime);
-  sprintf( fname, "hpcg_log_%04d.%02d.%02d.%02d.%02d.%02d.txt",
+  sprintf( fname, "hpcg%04d%02d%02dT%02d%02d%02d.txt",
       1900 + ptm->tm_year, ptm->tm_mon+1, ptm->tm_mday, ptm->tm_hour, ptm->tm_min, ptm->tm_sec );
 
   if (0 == params.comm_rank)
     HPCG_fout.open(fname);
   else {
 #if defined(HPCG_DEBUG) || defined(HPCG_DETAILED_DEBUG)
-    char local[15];
-    sprintf( local, "%d_", params.comm_rank );
-    sprintf( fname, "hpcg_log_%s%04.d%02d.%02d.%02d.%02d.%02d.txt", local,
-        1900 + ptm->tm_year, ptm->tm_mon+1, ptm->tm_mday, ptm->tm_hour, ptm->tm_min, ptm->tm_sec );
+    sprintf( fname, "hpcg%04d%02d%02dT%02d%02d%02d_%d.txt",
+        1900 + ptm->tm_year, ptm->tm_mon+1, ptm->tm_mday, ptm->tm_hour, ptm->tm_min, ptm->tm_sec, params.comm_rank );
     HPCG_fout.open(fname);
 #else
     HPCG_fout.open(NULLDEVICE);
 #endif
   }
 
+  free( iparams );
+
   return 0;
 }
