@@ -45,14 +45,18 @@ get_tbb_library_directory() {
         if [ $? -eq 0 ]; then
             __tbb_tmp_gcc_version=$(echo "${__tbb_tmp_gcc_version_full}" | egrep -o "^[0-9]+\.[0-9]+\.[0-9]+")
         fi
-        case "${__tbb_tmp_gcc_version}" in
-        4.[7-9]*|[5-9]* )
-            __tbb_tmp_lib_dir="gcc4.7";;
-        4.[4-6]* )
-            __tbb_tmp_lib_dir="gcc4.4";;
-        * )
-            __tbb_tmp_lib_dir="gcc4.1";;
-        esac
+        if [ -d "${TBBROOT}/lib/${__mkl_tmp_TARGET_ARCH}/gcc4.8" ]; then
+            __tbb_tmp_lib_dir="gcc4.8"
+        else
+            case "${__tbb_tmp_gcc_version}" in
+                4.[7-9]*|[5-9]* )
+                    __tbb_tmp_lib_dir="gcc4.7";;
+                4.[4-6]* )
+                    __tbb_tmp_lib_dir="gcc4.4";;
+                * )
+                    __tbb_tmp_lib_dir="gcc4.1";;
+            esac
+        fi
     fi
     echo ${__tbb_tmp_lib_dir}
 }
