@@ -19,9 +19,19 @@
 
 #ifndef _MKL_BLAS_H_
 #define _MKL_BLAS_H_
+#include <stddef.h>
 
 #include "mkl_types.h"
 
+#ifdef __GNUC__
+#define MKL_DEPRECATED __attribute__((deprecated))
+#elif defined(_MSC_VER)
+#define MKL_DEPRECATED __declspec(deprecated)
+#else
+#pragma message("WARNING: MKL {S,D}GEMM_ALLOC and {S,D}GEMM_FREE were declared deprecated. Use MKL {S,D}GEMM_PACK_GET_SIZE, MKL_MALLOC and MKL_FREE instead")
+#define MKL_DEPRECATED
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
@@ -309,13 +319,13 @@ void DZGEMV(const char *trans, const MKL_INT *m, const MKL_INT *n, const MKL_Com
 void SGEMM(const char *transa, const char *transb, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
            const float *alpha, const float *a, const MKL_INT *lda, const float *b, const MKL_INT *ldb,
            const float *beta, float *c, const MKL_INT *ldc);
-float* SGEMM_ALLOC(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
-MKL_INT SGEMM_PACK_GET_SIZE(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
+MKL_DEPRECATED float* SGEMM_ALLOC(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
+size_t SGEMM_PACK_GET_SIZE(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
 void SGEMM_PACK(const char *identifier, const char *trans, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
            const float *alpha, const float *src, const MKL_INT *ld, float *dest);
 void SGEMM_COMPUTE(const char *transa, const char *transb, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
            const float *a, const MKL_INT *lda, const float *b, const MKL_INT *ldb, const float *beta, float *c, const MKL_INT *ldc);
-void SGEMM_FREE(float *mat);
+MKL_DEPRECATED  void SGEMM_FREE(float *mat);
 void SGEMM_BATCH(const char *transa_array, const char *transb_array, const MKL_INT *m_array, const MKL_INT *n_array, const MKL_INT *k_array,
            const float *alpha_array, const float **a_array, const MKL_INT *lda_array, const float **b_array, const MKL_INT *ldb_array,
            const float *beta_array, float **c_array, const MKL_INT *ldc_array, const MKL_INT *group_count, const MKL_INT *group_size);
@@ -401,13 +411,13 @@ void CTRSM(const char *side, const char *uplo, const char *transa, const char *d
 void DGEMM(const char *transa, const char *transb, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
            const double *alpha, const double *a, const MKL_INT *lda, const double *b, const MKL_INT *ldb,
            const double *beta, double *c, const MKL_INT *ldc);
-double* DGEMM_ALLOC(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
-MKL_INT DGEMM_PACK_GET_SIZE(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
+MKL_DEPRECATED double* DGEMM_ALLOC(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
+size_t DGEMM_PACK_GET_SIZE(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
 void DGEMM_PACK(const char *identifier, const char *trans, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
            const double *alpha, const double *src, const MKL_INT *ld, double *dest);
 void DGEMM_COMPUTE(const char *transa, const char *transb, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
            const double *a, const MKL_INT *lda, const double *b, const MKL_INT *ldb, const double *beta, double *c, const MKL_INT *ldc);
-void DGEMM_FREE(double *mat);
+MKL_DEPRECATED void DGEMM_FREE(double *mat);
 void DGEMM_BATCH(const char *transa_array, const char *transb_array, const MKL_INT *m_array, const MKL_INT *n_array, const MKL_INT *k_array,
            const double *alpha_array, const double **a_array, const MKL_INT *lda_array, const double **b_array, const MKL_INT *ldb_array,
            const double *beta_array, double **c_array, const MKL_INT *ldc_array, const MKL_INT *group_count, const MKL_INT *group_size);
@@ -499,8 +509,8 @@ void GEMM_S16S16S32(const char *transa, const char *transb, const char *offsetc,
                     const MKL_INT16 *b, const MKL_INT *ldb, const MKL_INT16 *bo,
                     const float *beta, MKL_INT32 *c, const MKL_INT *ldc, const MKL_INT32 *co);
 
-MKL_INT GEMM_S8U8S32_PACK_GET_SIZE   (const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
-MKL_INT GEMM_S16S16S32_PACK_GET_SIZE (const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
+size_t GEMM_S8U8S32_PACK_GET_SIZE   (const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
+size_t GEMM_S16S16S32_PACK_GET_SIZE (const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
 
 void GEMM_S8U8S32_PACK     (const char *identifier, const char *trans, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
                             const void *src, const MKL_INT *ld, void *dest);
@@ -800,13 +810,13 @@ void dzgemv(const char *trans, const MKL_INT *m, const MKL_INT *n, const MKL_Com
 void sgemm(const char *transa, const char *transb, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
            const float *alpha, const float *a, const MKL_INT *lda, const float *b, const MKL_INT *ldb,
            const float *beta, float *c, const MKL_INT *ldc);
-float* sgemm_alloc(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
-MKL_INT sgemm_pack_get_size(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
+MKL_DEPRECATED float* sgemm_alloc(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
+size_t sgemm_pack_get_size(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
 void sgemm_pack(const char *identifier, const char *trans, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
            const float *alpha, const float *src, const MKL_INT *ld, float *dest);
 void sgemm_compute(const char *transa, const char *transb, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
            const float *a, const MKL_INT *lda, const float *b, const MKL_INT *ldb, const float *beta, float *c, const MKL_INT *ldc);
-void sgemm_free(float *mat);
+MKL_DEPRECATED void sgemm_free(float *mat);
 void sgemm_batch(const char *transa_array, const char *transb_array, const MKL_INT *m_array, const MKL_INT *n_array, const MKL_INT *k_array,
            const float *alpha_array, const float **a_array, const MKL_INT *lda_array, const float **b_array, const MKL_INT *ldb_array,
            const float *beta_array, float **c_array, const MKL_INT *ldc_array, const MKL_INT *group_count, const MKL_INT *group_size);
@@ -889,13 +899,13 @@ void ctrsm_batch(const char *side_array, const char *uplo_array, const char *tra
 void dgemm(const char *transa, const char *transb, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
            const double *alpha, const double *a, const MKL_INT *lda, const double *b, const MKL_INT *ldb,
            const double *beta, double *c, const MKL_INT *ldc);
-double* dgemm_alloc(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
-MKL_INT dgemm_pack_get_size(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
+MKL_DEPRECATED double* dgemm_alloc(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
+size_t dgemm_pack_get_size(const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
 void dgemm_pack(const char *identifier, const char *trans, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
            const double *alpha, const double *src, const MKL_INT *ld, double *dest);
 void dgemm_compute(const char *transa, const char *transb, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
            const double *a, const MKL_INT *lda, const double *b, const MKL_INT *ldb, const double *beta, double *c, const MKL_INT *ldc);
-void dgemm_free(double *mat);
+MKL_DEPRECATED void dgemm_free(double *mat);
 void dgemm_batch(const char *transa_array, const char *transb_array, const MKL_INT *m_array, const MKL_INT *n_array, const MKL_INT *k_array,
            const double *alpha_array, const double **a_array, const MKL_INT *lda_array, const double **b_array, const MKL_INT *ldb_array,
            const double *beta_array, double **c_array, const MKL_INT *ldc_array, const MKL_INT *group_count, const MKL_INT *group_size);
@@ -986,8 +996,8 @@ void gemm_s8u8s32(const char *transa, const char *transb, const char *offsetc,
                     const MKL_UINT8 *b, const MKL_INT *ldb, const MKL_INT8 *bo,
                     const float *beta, MKL_INT32 *c, const MKL_INT *ldc, const MKL_INT32 *co);
 
-MKL_INT gemm_s8u8s32_pack_get_size   (const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
-MKL_INT gemm_s16s16s32_pack_get_size (const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
+size_t gemm_s8u8s32_pack_get_size   (const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
+size_t gemm_s16s16s32_pack_get_size (const char *identifier, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k);
 void gemm_s8u8s32_pack     (const char *identifier, const char *trans, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
                             const void *src, const MKL_INT *ld, void *dest);
 void gemm_s16s16s32_pack   (const char *identifier, const char *trans, const MKL_INT *m, const MKL_INT *n, const MKL_INT *k,
@@ -1023,10 +1033,28 @@ mkl_jit_status_t mkl_cblas_jit_create_sgemm(void** jitter, const MKL_LAYOUT layo
                                             const MKL_INT m, const MKL_INT n, const MKL_INT k, 
                                             const float alpha, const MKL_INT lda, const MKL_INT ldb, 
                                             const float beta, const MKL_INT ldc);
+#ifndef mkl_jit_create_cgemm
+#define mkl_jit_create_cgemm mkl_cblas_jit_create_cgemm
+#endif
+mkl_jit_status_t mkl_cblas_jit_create_cgemm(void** jitter, const MKL_LAYOUT layout, const MKL_TRANSPOSE transa, const MKL_TRANSPOSE transb,
+                                            const MKL_INT m, const MKL_INT n, const MKL_INT k, 
+                                            const void* alpha, const MKL_INT lda, const MKL_INT ldb, 
+                                            const void* beta, const MKL_INT ldc);
+
+#ifndef mkl_jit_create_zgemm
+#define mkl_jit_create_zgemm mkl_cblas_jit_create_zgemm
+#endif
+mkl_jit_status_t mkl_cblas_jit_create_zgemm(void** jitter, const MKL_LAYOUT layout, const MKL_TRANSPOSE transa, const MKL_TRANSPOSE transb,
+                                            const MKL_INT m, const MKL_INT n, const MKL_INT k, 
+                                            const void* alpha, const MKL_INT lda, const MKL_INT ldb, 
+                                            const void* beta, const MKL_INT ldc);
+
 
 
 dgemm_jit_kernel_t mkl_jit_get_dgemm_ptr(const void* jitter);
 sgemm_jit_kernel_t mkl_jit_get_sgemm_ptr(const void* jitter);
+cgemm_jit_kernel_t mkl_jit_get_cgemm_ptr(const void* jitter);
+zgemm_jit_kernel_t mkl_jit_get_zgemm_ptr(const void* jitter);
 
 mkl_jit_status_t mkl_jit_destroy(void* jitter);
 
