@@ -23,6 +23,20 @@
 
 #include "mkl_types.h"
 
+
+#ifdef __GNUC__
+#define MKL_DEPRECATED_C __attribute__((deprecated))
+#elif defined(_MSC_VER)
+#ifdef _WIN32
+#define MKL_DEPRECATED_C __declspec(deprecated, dllexport)
+#else
+#define MKL_DEPRECATED_C __declspec(deprecated)
+#endif
+#else
+#pragma message("WARNING: MKL {S,D}GEMM_ALLOC and {S,D}GEMM_FREE were declared deprecated. Use MKL {S,D}GEMM_PACK_GET_SIZE, MKL_MALLOC and MKL_FREE instead")
+#define MKL_DEPRECATED_C
+#endif
+
 #ifdef __cplusplus
 extern "C" {            /* Assume C declarations for C++ */
 #endif /* __cplusplus */
@@ -39,14 +53,24 @@ extern "C" {            /* Assume C declarations for C++ */
  */
 #define CBLAS_INDEX size_t  /* this may vary between platforms */
 
-typedef enum {CblasRowMajor=101, CblasColMajor=102} CBLAS_LAYOUT;
-typedef enum {CblasNoTrans=111, CblasTrans=112, CblasConjTrans=113} CBLAS_TRANSPOSE;
-typedef enum {CblasUpper=121, CblasLower=122} CBLAS_UPLO;
-typedef enum {CblasNonUnit=131, CblasUnit=132} CBLAS_DIAG;
-typedef enum {CblasLeft=141, CblasRight=142} CBLAS_SIDE;
-typedef enum {CblasPacked=151} CBLAS_STORAGE;
-typedef enum {CblasAMatrix=161, CblasBMatrix=162} CBLAS_IDENTIFIER;
-typedef enum {CblasRowOffset=171, CblasColOffset=172, CblasFixOffset=173} CBLAS_OFFSET;
+enum CBLAS_LAYOUT {CblasRowMajor=101, CblasColMajor=102};
+enum CBLAS_TRANSPOSE {CblasNoTrans=111, CblasTrans=112, CblasConjTrans=113};
+enum CBLAS_UPLO {CblasUpper=121, CblasLower=122};
+enum CBLAS_DIAG {CblasNonUnit=131, CblasUnit=132};
+enum CBLAS_SIDE {CblasLeft=141, CblasRight=142};
+enum CBLAS_STORAGE {CblasPacked=151};
+enum CBLAS_IDENTIFIER {CblasAMatrix=161, CblasBMatrix=162};
+enum CBLAS_OFFSET {CblasRowOffset=171, CblasColOffset=172, CblasFixOffset=173};
+
+typedef enum CBLAS_LAYOUT CBLAS_LAYOUT;
+typedef enum CBLAS_TRANSPOSE CBLAS_TRANSPOSE;
+typedef enum CBLAS_UPLO CBLAS_UPLO;
+typedef enum CBLAS_DIAG CBLAS_DIAG;
+typedef enum CBLAS_SIDE CBLAS_SIDE;
+typedef enum CBLAS_STORAGE CBLAS_STORAGE;
+typedef enum CBLAS_IDENTIFIER CBLAS_IDENTIFIER;
+typedef enum CBLAS_OFFSET CBLAS_OFFSET;
+
 
 typedef CBLAS_LAYOUT CBLAS_ORDER; /* this for backward compatibility with CBLAS_ORDER */
 
@@ -774,9 +798,9 @@ void cblas_zher2k(const  CBLAS_LAYOUT Layout, const  CBLAS_UPLO Uplo,
 /*
  * Routines with prefixes S and D only
  */
-MKL_DECLSPEC float* cblas_sgemm_alloc(const  CBLAS_IDENTIFIER identifier,
+MKL_DEPRECATED_C float* cblas_sgemm_alloc(const  CBLAS_IDENTIFIER identifier,
                  const MKL_INT M, const MKL_INT N, const MKL_INT K);
-MKL_INT cblas_sgemm_pack_get_size(const  CBLAS_IDENTIFIER identifier,
+size_t cblas_sgemm_pack_get_size(const  CBLAS_IDENTIFIER identifier,
                             const MKL_INT M, const MKL_INT N, const MKL_INT K);
 void cblas_sgemm_pack(const  CBLAS_LAYOUT Layout, const  CBLAS_IDENTIFIER identifier,
                  const  CBLAS_TRANSPOSE Trans, const MKL_INT M, const MKL_INT N,
@@ -787,10 +811,10 @@ void cblas_sgemm_compute(const  CBLAS_LAYOUT Layout, const MKL_INT TransA,
                  const MKL_INT K, const float *A,
                  const MKL_INT lda, const float *B, const MKL_INT ldb,
                  const float beta, float *C, const MKL_INT ldc);
-void cblas_sgemm_free(float *dest);
-MKL_DECLSPEC double* cblas_dgemm_alloc(const  CBLAS_IDENTIFIER identifier,
+MKL_DEPRECATED_C void cblas_sgemm_free(float *dest);
+MKL_DEPRECATED_C double* cblas_dgemm_alloc(const  CBLAS_IDENTIFIER identifier,
                  const MKL_INT M, const MKL_INT N, const MKL_INT K);
-MKL_INT cblas_dgemm_pack_get_size(const  CBLAS_IDENTIFIER identifier,
+size_t cblas_dgemm_pack_get_size(const  CBLAS_IDENTIFIER identifier,
                             const MKL_INT M, const MKL_INT N, const MKL_INT K);
 void cblas_dgemm_pack(const  CBLAS_LAYOUT Layout, const  CBLAS_IDENTIFIER identifier,
                  const  CBLAS_TRANSPOSE Trans, const MKL_INT M, const MKL_INT N,
@@ -801,7 +825,7 @@ void cblas_dgemm_compute(const  CBLAS_LAYOUT Layout, const MKL_INT TransA,
                  const MKL_INT K, const double *A,
                  const MKL_INT lda, const double *B, const MKL_INT ldb,
                  const double beta, double *C, const MKL_INT ldc);
-void cblas_dgemm_free(double *dest);
+MKL_DEPRECATED_C void cblas_dgemm_free(double *dest);
 
 /*
  * Integer Routines
@@ -819,9 +843,9 @@ void cblas_gemm_s8u8s32(const CBLAS_LAYOUT Layout, const CBLAS_TRANSPOSE TransA,
                           const void *B, const MKL_INT ldb, const MKL_INT8 bo, const float beta,
                           MKL_INT32 *C, const MKL_INT ldc, const MKL_INT32 *cb);
 
-MKL_INT cblas_gemm_s8u8s32_pack_get_size(const  CBLAS_IDENTIFIER identifier,
+size_t cblas_gemm_s8u8s32_pack_get_size(const  CBLAS_IDENTIFIER identifier,
                                    const MKL_INT M, const MKL_INT N, const MKL_INT K);
-MKL_INT cblas_gemm_s16s16s32_pack_get_size(const  CBLAS_IDENTIFIER identifier,
+size_t cblas_gemm_s16s16s32_pack_get_size(const  CBLAS_IDENTIFIER identifier,
                                      const MKL_INT M, const MKL_INT N, const MKL_INT K);
 
 void cblas_gemm_s8u8s32_pack  (const  CBLAS_LAYOUT Layout, const  CBLAS_IDENTIFIER identifier,
@@ -831,16 +855,16 @@ void cblas_gemm_s16s16s32_pack(const  CBLAS_LAYOUT Layout, const  CBLAS_IDENTIFI
                  const  CBLAS_TRANSPOSE Trans, const MKL_INT M, const MKL_INT N, const MKL_INT K,
                  const MKL_INT16 *src, const MKL_INT ld, MKL_INT16 *dest);
 
-void cblas_gemm_s8u8s32_compute  (const  CBLAS_LAYOUT Layout, const CBLAS_TRANSPOSE TransA,
-                 const CBLAS_TRANSPOSE TransB, const CBLAS_OFFSET offsetc,
+void cblas_gemm_s8u8s32_compute  (const  CBLAS_LAYOUT Layout, const MKL_INT TransA,
+                 const MKL_INT TransB, const CBLAS_OFFSET offsetc,
                  const MKL_INT M, const MKL_INT N, const MKL_INT K, 
                  const float alpha,
                  const void *A, const MKL_INT lda, const MKL_INT8 ao,
                  const void *B, const MKL_INT ldb, const MKL_INT8 bo,
                  const float beta,
                  MKL_INT32 *C, const MKL_INT ldc, const MKL_INT32 *co);
-void cblas_gemm_s16s16s32_compute(const  CBLAS_LAYOUT Layout, const CBLAS_TRANSPOSE TransA,
-                 const CBLAS_TRANSPOSE TransB, const CBLAS_OFFSET offsetc,
+void cblas_gemm_s16s16s32_compute(const  CBLAS_LAYOUT Layout, const MKL_INT TransA,
+                 const MKL_INT TransB, const CBLAS_OFFSET offsetc,
                  const MKL_INT M, const MKL_INT N, const MKL_INT K, 
                  const float alpha,
                  const MKL_INT16 *A, const MKL_INT lda, const MKL_INT16 ao,
@@ -858,6 +882,7 @@ mkl_jit_status_t mkl_cblas_jit_create_dgemm(void** jitter, const MKL_LAYOUT layo
                                             const MKL_INT m, const MKL_INT n, const MKL_INT k, 
                                             const double alpha, const MKL_INT lda, const MKL_INT ldb, 
                                             const double beta, const MKL_INT ldc);
+
 #ifndef mkl_jit_create_sgemm
 #define mkl_jit_create_sgemm mkl_cblas_jit_create_sgemm
 #endif
@@ -865,13 +890,31 @@ mkl_jit_status_t mkl_cblas_jit_create_sgemm(void** jitter, const MKL_LAYOUT layo
                                             const MKL_INT m, const MKL_INT n, const MKL_INT k, 
                                             const float alpha, const MKL_INT lda, const MKL_INT ldb, 
                                             const float beta, const MKL_INT ldc);
+#ifndef mkl_jit_create_cgemm
+#define mkl_jit_create_cgemm mkl_cblas_jit_create_cgemm
+#endif
+mkl_jit_status_t mkl_cblas_jit_create_cgemm(void** jitter, const MKL_LAYOUT layout, const MKL_TRANSPOSE transa, const MKL_TRANSPOSE transb,
+                                            const MKL_INT m, const MKL_INT n, const MKL_INT k, 
+                                            const void* alpha, const MKL_INT lda, const MKL_INT ldb, 
+                                            const void* beta, const MKL_INT ldc);
+
+#ifndef mkl_jit_create_zgemm
+#define mkl_jit_create_zgemm mkl_cblas_jit_create_zgemm
+#endif
+mkl_jit_status_t mkl_cblas_jit_create_zgemm(void** jitter, const MKL_LAYOUT layout, const MKL_TRANSPOSE transa, const MKL_TRANSPOSE transb,
+                                            const MKL_INT m, const MKL_INT n, const MKL_INT k, 
+                                            const void* alpha, const MKL_INT lda, const MKL_INT ldb, 
+                                            const void* beta, const MKL_INT ldc);
+
+
 
 dgemm_jit_kernel_t mkl_jit_get_dgemm_ptr(const void* jitter);
 sgemm_jit_kernel_t mkl_jit_get_sgemm_ptr(const void* jitter);
+cgemm_jit_kernel_t mkl_jit_get_cgemm_ptr(const void* jitter);
+zgemm_jit_kernel_t mkl_jit_get_zgemm_ptr(const void* jitter);
 
 mkl_jit_status_t mkl_jit_destroy(void* jitter);
 
-
 #ifdef __cplusplus
 }
 #endif    /* __cplusplus */
