@@ -376,6 +376,138 @@
         END SUBROUTINE CLUSTER_SPARSE_SOLVER_SC_64_2D
       END INTERFACE
 
+!   operation names for the export routines
+      INTEGER*4, PARAMETER :: SPARSE_PTLUQT  = 0
+      INTEGER*4, PARAMETER :: SPARSE_DPTLUQT = 1
+
+!   data names for the export routines
+      INTEGER*4, PARAMETER :: SPARSE_PTLUQT_L  = 0
+      INTEGER*4, PARAMETER :: SPARSE_PTLUQT_U  = 1
+      INTEGER*4, PARAMETER :: SPARSE_PTLUQT_P  = 2
+      INTEGER*4, PARAMETER :: SPARSE_PTLUQT_Q  = 3
+      INTEGER*4, PARAMETER :: SPARSE_DPTLUQT_L = 4
+      INTEGER*4, PARAMETER :: SPARSE_DPTLUQT_U = 5
+      INTEGER*4, PARAMETER :: SPARSE_DPTLUQT_P = 6
+      INTEGER*4, PARAMETER :: SPARSE_DPTLUQT_Q = 7
+      INTEGER*4, PARAMETER :: SPARSE_DPTLUQT_D = 8
+
+      INTERFACE CLUSTER_SPARSE_SOLVER_GET_CSR_SIZE
+        SUBROUTINE CLUSTER_SPARSE_SOLVER_GET_CSR_SIZE_F(PT,DATANAME,LOCAL_NROWS,LOCAL_NNZ,COMM,ERROR)
+          USE MKL_CLUSTER_SPARSE_SOLVER_PRIVATE
+          TYPE(MKL_CLUSTER_SPARSE_SOLVER_HANDLE), INTENT(INOUT) :: PT(*)
+          INTEGER*4,        INTENT(IN)    :: DATANAME
+          INTEGER,          INTENT(OUT)   :: LOCAL_NROWS
+          INTEGER,          INTENT(OUT)   :: LOCAL_NNZ
+          INTEGER*4,        INTENT(IN)    :: COMM
+          INTEGER,          INTENT(OUT)   :: ERROR
+        END SUBROUTINE CLUSTER_SPARSE_SOLVER_GET_CSR_SIZE_F
+      END INTERFACE
+
+      INTERFACE CLUSTER_SPARSE_SOLVER_SET_CSR_PTRS
+        SUBROUTINE CLUSTER_SPARSE_SOLVER_SET_CSR_PTRS_D(PT,DATANAME,ROWPTR,COLINDX,VALS,COMM,ERROR)
+          USE MKL_CLUSTER_SPARSE_SOLVER_PRIVATE
+          TYPE(MKL_CLUSTER_SPARSE_SOLVER_HANDLE), INTENT(INOUT) :: PT(*)
+          INTEGER*4,        INTENT(IN)    :: DATANAME
+          INTEGER,          INTENT(IN)    :: ROWPTR(*)
+          INTEGER,          INTENT(IN)    :: COLINDX(*)
+          REAL(KIND=8),     INTENT(IN)    :: VALS(*)
+          INTEGER*4,        INTENT(IN)    :: COMM
+          INTEGER,          INTENT(OUT)   :: ERROR
+        END SUBROUTINE CLUSTER_SPARSE_SOLVER_SET_CSR_PTRS_D
+
+        SUBROUTINE CLUSTER_SPARSE_SOLVER_SET_CSR_PTRS_S(PT,DATANAME,ROWPTR,COLINDX,VALS,COMM,ERROR)
+          USE MKL_CLUSTER_SPARSE_SOLVER_PRIVATE
+          TYPE(MKL_CLUSTER_SPARSE_SOLVER_HANDLE), INTENT(INOUT) :: PT(*)
+          INTEGER*4,        INTENT(IN)    :: DATANAME
+          INTEGER,          INTENT(IN)    :: ROWPTR(*)
+          INTEGER,          INTENT(IN)    :: COLINDX(*)
+          REAL(KIND=4),     INTENT(IN)    :: VALS(*)
+          INTEGER*4,        INTENT(IN)    :: COMM
+          INTEGER,          INTENT(OUT)   :: ERROR
+        END SUBROUTINE CLUSTER_SPARSE_SOLVER_SET_CSR_PTRS_S
+
+        SUBROUTINE CLUSTER_SPARSE_SOLVER_SET_CSR_PTRS_DC(PT,DATANAME,ROWPTR,COLINDX,VALS,COMM,ERROR)
+          USE MKL_CLUSTER_SPARSE_SOLVER_PRIVATE
+          TYPE(MKL_CLUSTER_SPARSE_SOLVER_HANDLE), INTENT(INOUT) :: PT(*)
+          INTEGER*4,        INTENT(IN)    :: DATANAME
+          INTEGER,          INTENT(IN)    :: ROWPTR(*)
+          INTEGER,          INTENT(IN)    :: COLINDX(*)
+          COMPLEX(KIND=8),  INTENT(IN)    :: VALS(*)
+          INTEGER*4,        INTENT(IN)    :: COMM
+          INTEGER,          INTENT(OUT)   :: ERROR
+        END SUBROUTINE CLUSTER_SPARSE_SOLVER_SET_CSR_PTRS_DC
+
+        SUBROUTINE CLUSTER_SPARSE_SOLVER_SET_CSR_PTRS_SC(PT,DATANAME,ROWPTR,COLINDX,VALS,COMM,ERROR)
+          USE MKL_CLUSTER_SPARSE_SOLVER_PRIVATE
+          TYPE(MKL_CLUSTER_SPARSE_SOLVER_HANDLE), INTENT(INOUT) :: PT(*)
+          INTEGER*4,        INTENT(IN)    :: DATANAME
+          INTEGER,          INTENT(IN)    :: ROWPTR(*)
+          INTEGER,          INTENT(IN)    :: COLINDX(*)
+          COMPLEX(KIND=4),  INTENT(IN)    :: VALS(*)
+          INTEGER*4,        INTENT(IN)    :: COMM
+          INTEGER,          INTENT(OUT)   :: ERROR
+        END SUBROUTINE CLUSTER_SPARSE_SOLVER_SET_CSR_PTRS_SC
+
+      END INTERFACE
+
+      INTERFACE CLUSTER_SPARSE_SOLVER_SET_PTR
+        SUBROUTINE CLUSTER_SPARSE_SOLVER_SET_PTR_D(PT,DATANAME,PTR,COMM,ERROR)
+          USE MKL_CLUSTER_SPARSE_SOLVER_PRIVATE
+          TYPE(MKL_CLUSTER_SPARSE_SOLVER_HANDLE), INTENT(INOUT) :: PT(*)
+          INTEGER*4,        INTENT(IN)    :: DATANAME
+          REAL(KIND=8),     INTENT(IN)    :: PTR(*)
+          INTEGER*4,        INTENT(IN)    :: COMM
+          INTEGER,          INTENT(OUT)   :: ERROR
+        END SUBROUTINE CLUSTER_SPARSE_SOLVER_SET_PTR_D
+
+        SUBROUTINE CLUSTER_SPARSE_SOLVER_SET_PTR_S(PT,DATANAME,PTR,COMM,ERROR)
+          USE MKL_CLUSTER_SPARSE_SOLVER_PRIVATE
+          TYPE(MKL_CLUSTER_SPARSE_SOLVER_HANDLE), INTENT(INOUT) :: PT(*)
+          INTEGER*4,        INTENT(IN)    :: DATANAME
+          REAL(KIND=4),     INTENT(IN)    :: PTR(*)
+          INTEGER*4,        INTENT(IN)    :: COMM
+          INTEGER,          INTENT(OUT)   :: ERROR
+        END SUBROUTINE CLUSTER_SPARSE_SOLVER_SET_PTR_S
+
+        SUBROUTINE CLUSTER_SPARSE_SOLVER_SET_PTR_DC(PT,DATANAME,PTR,COMM,ERROR)
+          USE MKL_CLUSTER_SPARSE_SOLVER_PRIVATE
+          TYPE(MKL_CLUSTER_SPARSE_SOLVER_HANDLE), INTENT(INOUT) :: PT(*)
+          INTEGER*4,        INTENT(IN)    :: DATANAME
+          COMPLEX(KIND=8),  INTENT(IN)    :: PTR(*)
+          INTEGER*4,        INTENT(IN)    :: COMM
+          INTEGER,          INTENT(OUT)   :: ERROR
+        END SUBROUTINE CLUSTER_SPARSE_SOLVER_SET_PTR_DC
+
+        SUBROUTINE CLUSTER_SPARSE_SOLVER_SET_PTR_SC(PT,DATANAME,PTR,COMM,ERROR)
+          USE MKL_CLUSTER_SPARSE_SOLVER_PRIVATE
+          TYPE(MKL_CLUSTER_SPARSE_SOLVER_HANDLE), INTENT(INOUT) :: PT(*)
+          INTEGER*4,        INTENT(IN)    :: DATANAME
+          COMPLEX(KIND=4),  INTENT(IN)    :: PTR(*)
+          INTEGER*4,        INTENT(IN)    :: COMM
+          INTEGER,          INTENT(OUT)   :: ERROR
+        END SUBROUTINE CLUSTER_SPARSE_SOLVER_SET_PTR_SC
+
+        SUBROUTINE CLUSTER_SPARSE_SOLVER_SET_PTR_I(PT,DATANAME,PTR,COMM,ERROR)
+          USE MKL_CLUSTER_SPARSE_SOLVER_PRIVATE
+          TYPE(MKL_CLUSTER_SPARSE_SOLVER_HANDLE), INTENT(INOUT) :: PT(*)
+          INTEGER*4,        INTENT(IN)    :: DATANAME
+          INTEGER,          INTENT(IN)    :: PTR(*)
+          INTEGER*4,        INTENT(IN)    :: COMM
+          INTEGER,          INTENT(OUT)   :: ERROR
+        END SUBROUTINE CLUSTER_SPARSE_SOLVER_SET_PTR_I
+
+      END INTERFACE
+
+      INTERFACE CLUSTER_SPARSE_SOLVER_EXPORT
+        SUBROUTINE CLUSTER_SPARSE_SOLVER_EXPORT_F(PT,OPERATION,COMM,ERROR)
+          USE MKL_CLUSTER_SPARSE_SOLVER_PRIVATE
+          TYPE(MKL_CLUSTER_SPARSE_SOLVER_HANDLE), INTENT(INOUT) :: PT(*)
+          INTEGER*4,        INTENT(IN)    :: OPERATION
+          INTEGER*4,        INTENT(IN)    :: COMM
+          INTEGER,          INTENT(OUT)   :: ERROR
+        END SUBROUTINE CLUSTER_SPARSE_SOLVER_EXPORT_F
+      END INTERFACE
+
       END MODULE MKL_CLUSTER_SPARSE_SOLVER
 
 !DEC$ ENDIF
