@@ -48,6 +48,31 @@ void CLUSTER_SPARSE_SOLVER_64(
      const void *, const long long int *, const long long int *, long long int *, const long long int *, long long int *,
      const long long int *,       void *,       void *, const int *, long long int *);
 
+typedef enum mkl_dss_export_data {DSS_EXPORT_DATA_MIN = 0,
+                                  SPARSE_PTLUQT_L = 0,
+                                  SPARSE_PTLUQT_U,
+                                  SPARSE_PTLUQT_P,
+                                  SPARSE_PTLUQT_Q,
+                                  SPARSE_DPTLUQT_L,
+                                  SPARSE_DPTLUQT_U,
+                                  SPARSE_DPTLUQT_P,
+                                  SPARSE_DPTLUQT_Q,
+                                  SPARSE_DPTLUQT_D,
+                                  DSS_EXPORT_DATA_MAX = SPARSE_DPTLUQT_D} _MKL_DSS_EXPORT_DATA;
+
+typedef enum mkl_dss_export_operation {DSS_EXPORT_OPERATION_MIN = 0,
+                                       SPARSE_PTLUQT = 0,
+                                       SPARSE_DPTLUQT,
+                                       DSS_EXPORT_OPERATION_MAX = SPARSE_DPTLUQT} _MKL_DSS_EXPORT_OPERATION;
+
+void cluster_sparse_solver_get_csr_size(void *, const int, MKL_INT *, MKL_INT *, const int *, MKL_INT *);
+
+void cluster_sparse_solver_set_csr_ptrs(void *, const int, MKL_INT *, MKL_INT *, void *, const int *, MKL_INT *);
+
+void cluster_sparse_solver_set_ptr(void *, const int, void *, const int *, MKL_INT *);
+
+void cluster_sparse_solver_export(void *, const int, const int *, MKL_INT *);
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
