@@ -26,6 +26,15 @@
 
 #include "mkl_dss.h"
 
+#ifdef __GNUC__
+#define MKL_DEPRECATED __attribute__((deprecated))
+#elif defined(_MSC_VER)
+#define MKL_DEPRECATED __declspec(deprecated)
+#else
+#pragma message("WARNING: Routines pardiso_getenv and pardiso_setenv were declared deprecated. Use OOC configuration file or environment variables instead")
+#define MKL_DEPRECATED
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
@@ -87,11 +96,11 @@ enum PARDISO_ENV_PARAM {
 #define PARDISO_NULL_HANDLE           -102
 #define PARDISO_MEMORY_ERROR          -103
 
-MKL_INT pardiso_getenv ( const _MKL_DSS_HANDLE_t, const enum PARDISO_ENV_PARAM*, char* );
-MKL_INT PARDISO_GETENV ( const _MKL_DSS_HANDLE_t, const enum PARDISO_ENV_PARAM*, char* );
+MKL_DEPRECATED MKL_INT pardiso_getenv ( const _MKL_DSS_HANDLE_t, const enum PARDISO_ENV_PARAM*, char* );
+MKL_DEPRECATED MKL_INT PARDISO_GETENV ( const _MKL_DSS_HANDLE_t, const enum PARDISO_ENV_PARAM*, char* );
 
-MKL_INT pardiso_setenv ( _MKL_DSS_HANDLE_t, const enum PARDISO_ENV_PARAM*, const char* );
-MKL_INT PARDISO_SETENV ( _MKL_DSS_HANDLE_t, const enum PARDISO_ENV_PARAM*, const char* );
+MKL_DEPRECATED MKL_INT pardiso_setenv ( _MKL_DSS_HANDLE_t, const enum PARDISO_ENV_PARAM*, const char* );
+MKL_DEPRECATED MKL_INT PARDISO_SETENV ( _MKL_DSS_HANDLE_t, const enum PARDISO_ENV_PARAM*, const char* );
 
 
 /* Intel(R) MKL Progress routine */
