@@ -36,6 +36,7 @@ MODULE MKL_SERVICE
     INTEGER (KIND=4), PARAMETER, PUBLIC :: MKL_ENABLE_AVX512        = 4
     INTEGER (KIND=4), PARAMETER, PUBLIC :: MKL_ENABLE_AVX512_MIC_E1 = 5
     INTEGER (KIND=4), PARAMETER, PUBLIC :: MKL_ENABLE_AVX512_E1     = 6
+    INTEGER (KIND=4), PARAMETER, PUBLIC :: MKL_ENABLE_AVX512_E2     = 7
 
     INTEGER (KIND=4), PARAMETER, PUBLIC :: MKL_INTERFACE_LP64  = Z"00000000"
     INTEGER (KIND=4), PARAMETER, PUBLIC :: MKL_INTERFACE_ILP64 = Z"00000001"
@@ -64,6 +65,8 @@ MODULE MKL_SERVICE
     INTEGER (KIND=4), PARAMETER, PUBLIC :: MKL_CBWR_AVX512_MIC_E1  = 13
     INTEGER (KIND=4), PARAMETER, PUBLIC :: MKL_CBWR_AVX512_E1      = 14
 
+    INTEGER (KIND=4), PARAMETER, PUBLIC :: MKL_CBWR_STRICT         = 65536
+
     INTEGER (KIND=4), PARAMETER, PUBLIC :: MKL_CBWR_SUCCESS                 =  0
     INTEGER (KIND=4), PARAMETER, PUBLIC :: MKL_CBWR_ERR_INVALID_SETTINGS    = -1
     INTEGER (KIND=4), PARAMETER, PUBLIC :: MKL_CBWR_ERR_INVALID_INPUT       = -2
