@@ -1567,13 +1567,133 @@ MODULE MKL_SPBLAS
             IMPORT SPARSE_MATRIX_T
             IMPORT MATRIX_DESCR
             TYPE(SPARSE_MATRIX_T), INTENT(INOUT) :: A
-            INTEGER(C_INT)      , INTENT(IN) :: operation     ! SPARSE_OPERATION_NON_TRANSPOSE is default value for
+            INTEGER(C_INT)       , INTENT(IN) :: operation     ! SPARSE_OPERATION_NON_TRANSPOSE is default value for
                                                                ! infinite amount of calls
             TYPE(MATRIX_DESCR)   , INTENT(IN) :: descr         ! sparse_matrix_type_t + sparse_fill_mode_t + sparse_diag_type_t
             INTEGER              , INTENT(IN) :: expected_calls
             INTEGER(C_INT) MKL_SPARSE_SET_SYMGS_HINT
         END FUNCTION
 
+        FUNCTION MKL_SPARSE_SET_LU_SMOOTHER_HINT(A,operation,descr,expected_calls) &
+                 BIND(C, name='MKL_SPARSE_SET_LU_SMOOTHER_HINT')
+            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT
+            IMPORT SPARSE_MATRIX_T
+            IMPORT MATRIX_DESCR
+            TYPE(SPARSE_MATRIX_T), INTENT(INOUT) :: A
+            INTEGER(C_INT)       , INTENT(IN) :: operation   
+            TYPE(MATRIX_DESCR)   , INTENT(IN) :: descr          ! sparse_matrix_type_t + sparse_fill_mode_t + sparse_diag_type_t
+            INTEGER              , INTENT(IN) :: expected_calls
+            INTEGER(C_INT) MKL_SPARSE_SET_LU_SMOOTHER_HINT
+        END FUNCTION
+
+        FUNCTION MKL_SPARSE_S_LU_SMOOTHER(operation,A,descr,diag,approx_diag_inverse,x,rhs) &
+                 BIND(C, name='MKL_SPARSE_S_LU_SMOOTHER')
+            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_FLOAT
+            IMPORT SPARSE_MATRIX_T
+            IMPORT MATRIX_DESCR
+            INTEGER(C_INT)       , INTENT(IN) :: operation
+            TYPE(SPARSE_MATRIX_T), INTENT(IN) :: A
+            TYPE(MATRIX_DESCR)   , INTENT(IN) :: descr          ! sparse_matrix_type_t + sparse_fill_mode_t + sparse_diag_type_t
+            REAL(C_FLOAT), INTENT(IN)   , DIMENSION(*) :: diag
+            REAL(C_FLOAT), INTENT(IN)   , DIMENSION(*) :: approx_diag_inverse
+            REAL(C_FLOAT), INTENT(INOUT), DIMENSION(*) :: x
+            REAL(C_FLOAT), INTENT(IN)   , DIMENSION(*) :: rhs
+            INTEGER(C_INT) MKL_SPARSE_S_LU_SMOOTHER
+        END FUNCTION
+
+        FUNCTION MKL_SPARSE_D_LU_SMOOTHER(operation,A,descr,diag,approx_diag_inverse,x,rhs) &
+                 BIND(C, name='MKL_SPARSE_D_LU_SMOOTHER')
+            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_DOUBLE
+            IMPORT SPARSE_MATRIX_T
+            IMPORT MATRIX_DESCR
+            INTEGER(C_INT)       , INTENT(IN) :: operation
+            TYPE(SPARSE_MATRIX_T), INTENT(IN) :: A
+            TYPE(MATRIX_DESCR)   , INTENT(IN) :: descr          ! sparse_matrix_type_t + sparse_fill_mode_t + sparse_diag_type_t
+            REAL(C_DOUBLE), INTENT(IN)   , DIMENSION(*) :: diag
+            REAL(C_DOUBLE), INTENT(IN)   , DIMENSION(*) :: approx_diag_inverse
+            REAL(C_DOUBLE), INTENT(INOUT), DIMENSION(*) :: x
+            REAL(C_DOUBLE), INTENT(IN)   , DIMENSION(*) :: rhs
+            INTEGER(C_INT) MKL_SPARSE_D_LU_SMOOTHER
+        END FUNCTION
+
+        FUNCTION MKL_SPARSE_C_LU_SMOOTHER(operation,A,descr,diag,approx_diag_inverse,x,rhs) &
+                 BIND(C, name='MKL_SPARSE_C_LU_SMOOTHER')
+            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_FLOAT_COMPLEX
+            IMPORT SPARSE_MATRIX_T
+            IMPORT MATRIX_DESCR
+            INTEGER(C_INT)       , INTENT(IN) :: operation
+            TYPE(SPARSE_MATRIX_T), INTENT(IN) :: A
+            TYPE(MATRIX_DESCR)   , INTENT(IN) :: descr          ! sparse_matrix_type_t + sparse_fill_mode_t + sparse_diag_type_t
+            COMPLEX(C_FLOAT_COMPLEX), INTENT(IN)   , DIMENSION(*) :: diag
+            COMPLEX(C_FLOAT_COMPLEX), INTENT(IN)   , DIMENSION(*) :: approx_diag_inverse
+            COMPLEX(C_FLOAT_COMPLEX), INTENT(INOUT), DIMENSION(*) :: x
+            COMPLEX(C_FLOAT_COMPLEX), INTENT(IN)   , DIMENSION(*) :: rhs
+            INTEGER(C_INT) MKL_SPARSE_C_LU_SMOOTHER
+        END FUNCTION
+
+        FUNCTION MKL_SPARSE_Z_LU_SMOOTHER(operation,A,descr,diag,approx_diag_inverse,x,rhs) &
+                 BIND(C, name='MKL_SPARSE_Z_LU_SMOOTHER')
+            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_DOUBLE_COMPLEX
+            IMPORT SPARSE_MATRIX_T
+            IMPORT MATRIX_DESCR
+            INTEGER(C_INT)       , INTENT(IN) :: operation
+            TYPE(SPARSE_MATRIX_T), INTENT(IN) :: A
+            TYPE(MATRIX_DESCR)   , INTENT(IN) :: descr          ! sparse_matrix_type_t + sparse_fill_mode_t + sparse_diag_type_t
+            COMPLEX(C_DOUBLE_COMPLEX), INTENT(IN)   , DIMENSION(*) :: diag
+            COMPLEX(C_DOUBLE_COMPLEX), INTENT(IN)   , DIMENSION(*) :: approx_diag_inverse
+            COMPLEX(C_DOUBLE_COMPLEX), INTENT(INOUT), DIMENSION(*) :: x
+            COMPLEX(C_DOUBLE_COMPLEX), INTENT(IN)   , DIMENSION(*) :: rhs
+            INTEGER(C_INT) MKL_SPARSE_Z_LU_SMOOTHER
+        END FUNCTION
+
+        FUNCTION MKL_SPARSE_S_UPDATE_VALUES(A,nvalues,indx,indy,values) &
+                 BIND(C, name='MKL_SPARSE_S_UPDATE_VALUES')
+            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_FLOAT
+            IMPORT SPARSE_MATRIX_T
+            TYPE(SPARSE_MATRIX_T), INTENT(INOUT)            :: A
+            INTEGER              , INTENT(IN)               :: nvalues
+            INTEGER              , INTENT(IN), DIMENSION(*) :: indx
+            INTEGER              , INTENT(IN), DIMENSION(*) :: indy
+            REAL(C_FLOAT)        , INTENT(IN), DIMENSION(*) :: values
+            INTEGER(C_INT) MKL_SPARSE_S_UPDATE_VALUES
+        END FUNCTION
+
+        FUNCTION MKL_SPARSE_D_UPDATE_VALUES(A,nvalues,indx,indy,values) &
+                 BIND(C, name='MKL_SPARSE_D_UPDATE_VALUES')
+            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_DOUBLE
+            IMPORT SPARSE_MATRIX_T
+            TYPE(SPARSE_MATRIX_T), INTENT(INOUT)            :: A
+            INTEGER              , INTENT(IN)               :: nvalues
+            INTEGER              , INTENT(IN), DIMENSION(*) :: indx
+            INTEGER              , INTENT(IN), DIMENSION(*) :: indy
+            REAL(C_DOUBLE)       , INTENT(IN), DIMENSION(*) :: values
+            INTEGER(C_INT) MKL_SPARSE_D_UPDATE_VALUES
+        END FUNCTION
+
+        FUNCTION MKL_SPARSE_C_UPDATE_VALUES(A,nvalues,indx,indy,values) &
+                 BIND(C, name='MKL_SPARSE_C_UPDATE_VALUES')
+            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_FLOAT_COMPLEX
+            IMPORT SPARSE_MATRIX_T
+            TYPE(SPARSE_MATRIX_T)   , INTENT(INOUT)            :: A
+            INTEGER                 , INTENT(IN)               :: nvalues
+            INTEGER                 , INTENT(IN), DIMENSION(*) :: indx
+            INTEGER                 , INTENT(IN), DIMENSION(*) :: indy
+            COMPLEX(C_FLOAT_COMPLEX), INTENT(IN), DIMENSION(*) :: values
+            INTEGER(C_INT) MKL_SPARSE_C_UPDATE_VALUES
+        END FUNCTION
+
+        FUNCTION MKL_SPARSE_Z_UPDATE_VALUES(A,nvalues,indx,indy,values) &
+                 BIND(C, name='MKL_SPARSE_Z_UPDATE_VALUES')
+            USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_DOUBLE_COMPLEX
+            IMPORT SPARSE_MATRIX_T
+            TYPE(SPARSE_MATRIX_T)    , INTENT(INOUT)            :: A
+            INTEGER                  , INTENT(IN)               :: nvalues
+            INTEGER                  , INTENT(IN), DIMENSION(*) :: indx
+            INTEGER                  , INTENT(IN), DIMENSION(*) :: indy
+            COMPLEX(C_DOUBLE_COMPLEX), INTENT(IN), DIMENSION(*) :: values
+            INTEGER(C_INT) MKL_SPARSE_Z_UPDATE_VALUES
+        END FUNCTION
+
     END INTERFACE
 
 END MODULE MKL_SPBLAS
