@@ -51,6 +51,7 @@ extern "C" {
 #define VSL_RNG_ERROR_INVALID_BRNG_INDEX        -1000
 #define VSL_RNG_ERROR_LEAPFROG_UNSUPPORTED      -1002
 #define VSL_RNG_ERROR_SKIPAHEAD_UNSUPPORTED     -1003
+#define VSL_RNG_ERROR_SKIPAHEADEX_UNSUPPORTED   -1004
 #define VSL_RNG_ERROR_BRNGS_INCOMPATIBLE        -1005
 #define VSL_RNG_ERROR_BAD_STREAM                -1006
 #define VSL_RNG_ERROR_BRNG_TABLE_FULL           -1007
@@ -371,8 +372,8 @@ extern "C" {
 /*
 //  INITIALIZATION METHODS FOR USER-DESIGNED BASIC RANDOM NUMBER GENERATORS.
 //  Each BRNG must support at least VSL_INIT_METHOD_STANDARD initialization
-//  method. In addition, VSL_INIT_METHOD_LEAPFROG and VSL_INIT_METHOD_SKIPAHEAD
-//  initialization methods can be supported.
+//  method. In addition, VSL_INIT_METHOD_LEAPFROG, VSL_INIT_METHOD_SKIPAHEAD and
+//  VSL_INIT_METHOD_SKIPAHEADEX initialization methods can be supported.
 //
 //  If VSL_INIT_METHOD_LEAPFROG is not supported then initialization routine
 //  must return VSL_RNG_ERROR_LEAPFROG_UNSUPPORTED error code.
@@ -380,13 +381,16 @@ extern "C" {
 //  If VSL_INIT_METHOD_SKIPAHEAD is not supported then initialization routine
 //  must return VSL_RNG_ERROR_SKIPAHEAD_UNSUPPORTED error code.
 //
+//  If VSL_INIT_METHOD_SKIPAHEADEX is not supported then initialization routine
+//  must return VSL_RNG_ERROR_SKIPAHEADEX_UNSUPPORTED error code.
+//
 //  If there is no error during initialization, the initialization routine must
 //  return VSL_ERROR_OK code.
 */
-#define VSL_INIT_METHOD_STANDARD  0
-#define VSL_INIT_METHOD_LEAPFROG  1
-#define VSL_INIT_METHOD_SKIPAHEAD 2
-
+#define VSL_INIT_METHOD_STANDARD    0
+#define VSL_INIT_METHOD_LEAPFROG    1
+#define VSL_INIT_METHOD_SKIPAHEAD   2
+#define VSL_INIT_METHOD_SKIPAHEADEX 3
 
 /*
 //++
@@ -661,6 +665,25 @@ extern "C" {
    VSL_RNG_METHOD_BETA_CJA | VSL_RNG_METHOD_ACCURACY_FLAG
     /* accurate mode of vsl{d,s}RngBeta */
 
+
+/*
+// ChiSquare
+//
+// Comments:
+// v = 1, v = 3               - chi-square distributed random number is
+//                              generated as a sum of squares of v independent
+//                              normal random numbers;
+// v is even and v = 16       - chi-square distributed random number is
+//                              generated using the following formula:
+//                              x = -2*ln(u[0]*...*u[v/2-1]),
+//                              where u[i] - random numbers uniformly
+//                              distributed over the interval (0,1);
+// v > 16, v is odd and v > 3 - chi-square distribution reduces to gamma
+//                              distribution;
+*/
+#define VSL_RNG_METHOD_CHISQUARE_CHI2GAMMA 0 /* vsl{d,s}RngChiSquare */
+
+
 /*
 // Bernoulli
 //
