@@ -276,6 +276,11 @@ _Mkl_Api(int,vslSkipAheadStream,(VSLStreamStatePtr  , const long long int  ))
 _mkl_api(int,vslskipaheadstream,(VSLStreamStatePtr *, const long long int *))
 _MKL_API(int,VSLSKIPAHEADSTREAM,(VSLStreamStatePtr *, const long long int *))
 
+/* SkipAheadStreamEx - skip-ahead extended method */
+_Mkl_Api(int,vslSkipAheadStreamEx,(VSLStreamStatePtr  , const MKL_INT  , const MKL_UINT64[]))
+_mkl_api(int,vslskipaheadstreamex,(VSLStreamStatePtr *, const MKL_INT *, const MKL_UINT64[]))
+_MKL_API(int,VSLSKIPAHEADSTREAMEX,(VSLStreamStatePtr *, const MKL_INT *, const MKL_UINT64[]))
+
 /* GetStreamStateBrng - get BRNG associated with given stream */
 _Mkl_Api(int,vslGetStreamStateBrng,(const VSLStreamStatePtr  ))
 _mkl_api(int,vslgetstreamstatebrng,(const VSLStreamStatePtr *))
