@@ -45,29 +45,29 @@ while [ $# -gt 0 ] ; do
 	shift
 done
 
-PSXE_LOCATION=$PSXE_ROOT/parallel_studio_xe_2019.4.070
-CNL_LOCATION=$CNL_ROOT/compilers_and_libraries_2019.4.243
-ADVISOR_LOCATION=$PSXE_ROOT/advisor_2019
-INSPECTOR_LOCATION=$PSXE_ROOT/inspector_2019
-AMPLIFIER_LOCATION=$PSXE_ROOT/vtune_amplifier_2019
-CLCK_LOCATION=$PSXE_ROOT//clck/2019.4.0
-ITAC_LOCATION=$PSXE_ROOT/itac/2019.4.036
-IDE_LOCATION=$CNL_ROOT/ide_support_2019
-DOC_LOCATION=$PSXE_ROOT/documentation_2019
-SAMPLES_LOCATION=$PSXE_ROOT/samples_2019
+PSXE_LOCATION=$PSXE_ROOT/parallel_studio_xe_2020.0.088
+CNL_LOCATION=$CNL_ROOT/compilers_and_libraries_2020.0.166
+ADVISOR_LOCATION=$PSXE_ROOT/advisor_2020
+INSPECTOR_LOCATION=$PSXE_ROOT/inspector_2020
+AMPLIFIER_LOCATION=$PSXE_ROOT/vtune_profiler_2020
+CLCK_LOCATION=$PSXE_ROOT//clck/2019.6
+ITAC_LOCATION=$PSXE_ROOT/itac/2020.0.015
+IDE_LOCATION=$CNL_ROOT/ide_support_2020
+DOC_LOCATION=$PSXE_ROOT/documentation_2020
+SAMPLES_LOCATION=$PSXE_ROOT/samples_2020
 MAN_LOCATION=$CNL_ROOT/man
 
 # <base_directory>	<symlink>	<target>
 LINKS="
 $PSXE_LOCATION	clck_2019	$CLCK_LOCATION
-$PSXE_LOCATION	itac_2019	$ITAC_LOCATION
-$PSXE_LOCATION	advisor_2019	$ADVISOR_LOCATION
-$PSXE_LOCATION	inspector_2019	$INSPECTOR_LOCATION
-$PSXE_LOCATION	vtune_amplifier_2019	$AMPLIFIER_LOCATION
-$PSXE_LOCATION	compilers_and_libraries_2019	$CNL_LOCATION
-$PSXE_LOCATION	documentation_2019	$DOC_LOCATION
-$PSXE_LOCATION	ide_support_2019	$IDE_LOCATION
-$PSXE_LOCATION	samples_2019	$SAMPLES_LOCATION
+$PSXE_LOCATION	itac_2020	$ITAC_LOCATION
+$PSXE_LOCATION	advisor_2020	$ADVISOR_LOCATION
+$PSXE_LOCATION	inspector_2020	$INSPECTOR_LOCATION
+$PSXE_LOCATION	vtune_profiler_2020	$AMPLIFIER_LOCATION
+$PSXE_LOCATION	compilers_and_libraries_2020	$CNL_LOCATION
+$PSXE_LOCATION	documentation_2020	$DOC_LOCATION
+$PSXE_LOCATION	ide_support_2020	$IDE_LOCATION
+$PSXE_LOCATION	samples_2020	$SAMPLES_LOCATION
 $PSXE_LOCATION	man	$MAN_LOCATION
 "
 
